'++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
' script: weathercom_xml.vb
' 	Revision 	Date		Programmer	Ccomment
'	1.4			11/13/2011	CFGuy		Added ability to run a script at the end of the download/import process
'	1.3			09/05/2011	CFGuy		Split into functions.  Added function to clear old ini data
'	1.2  		02/06/2009	dmurphy		Fixed some "F bugs
'	1.1  		01/31/2009	dmurphy		Initial VB.Net Version
' Main - Calls the different import functions
' getINIValues - Sets the public ini values for devices
' convertMPH - converts mph to kmph
' directionText - Converts the abbreviated direction to readable text  SE = Southeast
' downloadNOAAForecast - downloads the NOAA XML forecast file
' downloadNOAAXML - downloads the NOAA XML current condition file
' downloadWUXML - downloads the weather underground XML files
' downloadWWOXML - downloads the Weather Underground XML current condtion and forecst XML file
' getFeelsLike - takes the temp and calculates the feels like temp, if not provided in the XML file
' importCondition - import the data from the Weather Underground condtion XML file
' resetHiLowValues - resets the daily hi low values at first run of the current day
' saveConditionIcon - takes a URL and saves the image to the local hard drive
' setDailyHiLow - checks for hi or low temperature extremes when the script runs
' setDeviceBarometer - sets the device string for Barometer
' setDeviceCondImage - sets the images to be displayed in the logo bar
' setDeviceCondition - set the device string for Condition
' setDeviceDoTheDew - set the device string for Dewpoint
' setDeviceForecast - set the device strings for the Forecast devices
' setDeviceHumidity - set the device string for Humidity
' setDeviceLike - set the device string for Feels Like Temperature
' setDeviceTemp - set the device string for Temperature
' setDeviceUpdated - set the device string for Last Updated
' setDeviceVisibility - set the device string for Visibility
' setDeviceWindDir - set the device string for Wind direction
' setDeviceWindDeg - set the device string for Wind degrees
' setDeviceWindGust - set the device string for Wind gusts
' setDeviceWindSpeed - set the device string for Wind Speed
' weatherNOAAData - import function for NOAA current conditions XML file
' weatherNOAAForecast - import function for NOAA forecast XML file
' weatherWUData - calls the correct import function for the various Weather Underground XML files
' weatherWWOData - import function for World Weather Online
' XMLFileExists - checks to see if a submitted XML file exists
'++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Option Strict On
Option Explicit On
Imports VB = Microsoft.VisualBasic
Imports System.IO
Imports System.Xml 
Public Dim debugMode As Boolean = False
Public Dim sINI as String = "weathercom_xml.ini"
Public Dim IName as String = "weatherXML"
Public Dim sTableStartCode as String = ""
Public DIm sMapTableStartCode as String = ""
Public Dim sTableMidCode as String = ""
Public Dim sTableEndCode as String = ""
Public Dim UseIcons as Boolean = True
Public Dim useHeadings as Boolean = True
Public Dim useHeadingStyle as String = ""
Public Dim UseMarquee as Boolean = True
Public Dim innerHeading as String = ""


'++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Sub Main(Optional ByVal sParam as String = "")
	Dim sWhereFrom as String
	sWhereFrom = hs.GetINISetting("settings","xmlSource","",sINI)
	getINIValues()
	if debugMode = True Then
		hs.WriteLog(IName,"weatherXML import started.")
	End if
	' reset the daily values
	resetHiLowValues()
	Select Case lCase(sWhereFrom)
		Case "noaa"
			if hs.GetINISetting("Settings","useForCurrent","noaa",sINI) = "noaa" Then
				weatherNOAAData()
			End if
			if hs.GetINISetting("Settings","useForForecast","noaa",sINI) = "noaa" Then
				weatherNOAAForecast()
			End if
		Case "wu"
			weatherWUData()
		Case "wwo"
			weatherWWOData()
		Case Else
			if hs.GetINISetting("Settings","useForCurrent","noaa",sINI) = "noaa" Then
				weatherNOAAData()
			End if
			if hs.GetINISetting("Settings","useForForecast","noaa",sINI) = "noaa" Then
				weatherNOAAForecast()
			End if
	End Select
	if sWhereFrom <> "wu" Then
		weatherWUData()
	End if
	' Map 1
	hs.RunEx("AZ_weatherXML_web.vb","setDeviceMap1","",True)
	' Map 2
	hs.RunEx("AZ_weatherXML_web.vb","setDeviceMap2","",True)
	' Set the last spoken device
	hs.RunEx("AZ_weathercom_xml_speak.vb","Main","False")
	hs.SaveINISetting ("WeatherInfo","LastUpdate",Now(),sINI)
	if hs.GetINISetting("Settings","saveToDB","False",sINI) = "True" Then
		hs.RunEx("AZ_weatherXML_db.vb","saveToDatabase","",True)
	End if
	if hs.GetINISetting("Settings","runMCSTemp","False",sINI) = "True" Then
		hs.RunEx("AZ_weatherXML_db.vb","insertMCSTemp","",True)
	End if
	if len(trim(hs.GetINISetting("Settings","runScript","",sINI))) > 0 Then
		hs.RunEx(hs.GetINISetting("Settings","runScript","",sINI),"Main","",False)
	End if
	hs.WriteLog(IName,"weatherXML import finished.")
End Sub

Sub getINIValues()
	Dim fs as Object
	fs = hs.CreateStringClass
		debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
		UseIcons = hs.GetINISetting ("Settings","UseIcons","True",sINI)
		useHeadings = hs.GetINISetting ("Settings","useHeadings",true,sINI)
		innerHeading = hs.GetINISetting ("Settings","useHeadingsStyle","",sINI)
		UseMarquee = hs.GetINISetting ("Settings","UseMarquee","0",sINI)
		sTableStartCode = hs.GetINISetting("Settings","TableStartCode","",sINI)
		sMapTableStartCode = hs.GetINISetting("Settings","MapTableStartCode","",sINI)
		sTableMidCode = hs.GetINISetting("Settings","TableMidCode","",sINI)
		sTableEndCode = hs.GetINISetting("Settings","TableEndCode","",sINI)
		fs.Add("<span style=""")
		fs.Add(innerHeading)
		fs.Add(""">")
		useHeadingStyle=fs.Value
	fs = Nothing
End Sub

Function convertMPH(ByVal nMPH as Single) as String
	Dim nResult as Single
	Dim sConvert as String
	if isNumeric(nMPH) Then
		nResult = nMPH*1.609344
		sConvert = nResult.toString("0.0")
	Else
		nResult = nMPH
		sConvert = nResult.toString
	End if
	if debugMode = True Then
		hs.WriteLog(IName,"Convert: " & nMPH & " to " & sConvert)
	End if
	return sConvert
End Function

Function directionText(ByVal strDirection As String) As String
    Dim txt As String
    Select Case UCase(trim(strDirection))
        Case "E"
            txt = "Oost"
        Case "ENE"
            txt = "Oost Noordoost"
        Case "ESE"
            txt = "Oost Zuidoost"
        Case "N"
            txt = "Noord"
        Case "NE"
            txt = "Noordoost"
        Case "NNE"
            txt = "Noord Noordoost"
        Case "NNW"
            txt = "Noord Noordwest"
        Case "NW"
            txt = "Noordwest"
        Case "S"
            txt = "Zuid"
        Case "SE"
            txt = "ZuidoostSoutheast"
        Case "SSE"
            txt = "Zuid Zuidoost"
        Case "SSW"
            txt = "Zuid Zuidwest"
        Case "SW"
            txt = "Zuidwest"
        Case "W"
            txt = "West"
        Case "WNW"
            txt = "West Noordwest"
        Case "WSW"
            txt = "West Zuidwest"
        Case Else
            txt = strDirection
    End Select
    Return txt
End Function

Function downloadNOAAForecast(Optional ByVal sParm as String = "")
	Dim intmintime as Integer
	Dim fs, FSO, xf as Object
	Dim sURl, NOAAForecastDomain, NOAAForecastURL1, NOAAForecastURL2, NOAAForecastURL3, NOAAForecastlat, NOAAForecastlon as String
	Dim lastran, sFileName, sXMLCont, sFile2 as String
	fs = hs.CreateStringClass
		lastran = hs.GetINISetting("Settings","lastranNF","",sINI)
		intmintime= CInt(hs.GetINISetting("Settings","mintime",2,sINI))
		if IsNumeric(intmintime) Then
			if intmintime < 2 Then
				intmintime = 2
			End if
		End if
		if NOT IsDate(lastran) Then
			hs.SaveINISetting("Settings","lastranNF",DateAdd("n",-15,Now),sINI)
			lastran = hs.GetINISetting("Settings","lastranNF","",sINI)
		End if
		fs.Add(hs.GetAppPath)
		fs.Add("\data\weathercom_xml\forecast.xml")
		sFileName = fs.Value
		fs.Reset
		if DateDiff("n",lastran,Now) >= intmintime Then
			NOAAForecastDomain= hs.GetINISetting("settings","NOAAForecastDomain","http://forecast.weather.gov/",sINI)
			NOAAForecastURL1= hs.GetINISetting("settings","NOAAForecastURL1","MapClick.php?lat=",sINI)
			NOAAForecastURL2= hs.GetINISetting("settings","NOAAForecastURL2","&lon=",sINI)
			NOAAForecastURL3= hs.GetINISetting("settings","NOAAForecastURL3","&FcstType=dwml",sINI)
			NOAAForecastlat= hs.GetINISetting("settings","NOAAForecastlat","38.96290",sINI)
			NOAAForecastlon= hs.GetINISetting("settings","NOAAForecastlon","-95.25540",sINI)
			fs.Add(NOAAForecastURL1)
			fs.Add(NOAAForecastlat)
			fs.Add(NOAAForecastURL2)
			fs.Add(NOAAForecastlon)
			fs.Add(NOAAForecastURL3)
			sURL = fs.Value
			fs.Reset
			sXMLCont = hs.GetURL (NOAAForecastDomain,sURL,FALSE,80)
			sXMLCont = replace(sXMLCont, "ISO-8859-1", "utf-8") 
			if debugMode = true Then
				fs.Add("Downloading the forecast XML file from: ")
				fs.Add(NOAAForecastDomain)
				fs.Add(sURL)
				hs.WriteLog(IName,fs.Value)
				fs.Reset
			End if
			FSO = CreateObject("Scripting.FileSystemObject")
				xf = FSO.CreateTextFile (sFileName,True)
					xf.WriteLine (sXMLCont)
					xf.Close
				xf = Nothing
				hs.SaveINISetting("Settings","lastranNF",Now,sINI)
				sFile2 = hs.GetINISetting("Settings","xmlweblocation","",sINI)
				if len(trim(sFile2)) > 0 Then
					fs.Add(hs.GetAPPPath)
					fs.Add("\html\")
					fs.Add(sFile2)
					fs.Add("\forecast.xml")
					xf = FSO.CreateTextFile (fs.Value,True)
						xf.WriteLine (sXMLCont)
						xf.Close
					xf = Nothing
					fs.Reset
				End if
			FSO = Nothing
		End if
	fs = Nothing
	Return sFileName
End Function

Function downloadNOAAXML(Optional ByVal sParm as String = "")
	Dim intmintime as Integer
	Dim dx, FSO, xf as Object
	Dim strCodeArea, sFileName, strPartnerID, strDomain, lastran, sXMLFile, sXMLCont, sFile2 as String
	strPartnerID = hs.GetINISetting ("Settings","NOAAStation","",sINI)
	strCodeArea = hs.GetINISetting ("Settings","NOAAURL","",sINI)
	strDomain = hs.GetINISetting ("Settings","NOAADomain","",sINI)
	Try
		sXMLFile = "N/A"
		dx = hs.CreateStringClass
			if len(trim(strDomain)) = 0 OR len(trim(strPartnerID)) = 0 OR len(trim(strCodeArea)) = 0 Then
				dx.Add("The NOAA Domain (")
				dx.Add(strDomain)
				dx.Add("), URL (")
				dx.Add(strCodeArea)
				dx.Add(") or NOAA station code (")
				dx.Add(strPartnerID)
				dx.Add(") is missing.  The XML file can not be downloaded without that information.  ")
				dx.Add("Please read the instructions on how to obtain and enter the missing information.")
				hs.WriteLog(IName,dx.Value)
				dx.Reset
				Exit Function
			End if
			lastran = hs.GetINISetting ("Settings","lastranNC","",sINI)
			intmintime= CInt(hs.GetINISetting ("Settings","mintime",5,sINI))
			if IsNumeric(intmintime) Then
				if intmintime < 5 Then
					intmintime = 5
				End if
			End if
			if NOT IsDate(lastran) Then
				hs.SaveINISetting("Settings","lastranNC",DateAdd("n",-15,Now),sINI)
				lastran = hs.GetINISetting("Settings","lastranNC","",sINI)
			End if
			dx.Add(hs.GetAppPath)
			dx.Add("\data\weathercom_xml\weathercom.xml")
			sXMLFile = dx.Value
			dx.Reset
			if DateDiff("n",lastran,Now) >= intmintime Then
				dx.Add(strCodeArea)
				dx.Add(strPartnerID)
				dx.Add(".xml")
				sFileName = dx.Value
				sXMLCont = hs.GetURL (strDomain, dx.Value,FALSE,80)
				dx.Reset
				sXMLCont = replace(sXMLCont, "ISO-8859-1", "utf-8") 
				if debugMode = true Then
					dx.Add("Downloading the current conditions XML file: ")
					dx.Add(strDomain)
					dx.Add(sFileName)
					hs.WriteLog(IName,dx.Value)
					dx.Reset
				End if
				FSO = CreateObject("Scripting.FileSystemObject")
					xf = FSO.CreateTextFile (sXMLFile,True)
						xf.WriteLine (sXMLCont)
						xf.Close
					xf = Nothing
					hs.SaveINISetting ("Settings","lastranNC",Now,sINI)
					sFile2 = hs.GetINISetting ("Settings","xmlweblocation","",sINI)
					if len(trim(sFile2)) > 0 Then
						dx.Add(hs.GetAPPPath)
						dx.Add("\html\")
						dx.Add(sFile2)
						dx.Add("\weathercom.xml")
						xf = FSO.CreateTextFile (dx.Value,True)
							xf.WriteLine (sXMLCont)
							xf.Close
						xf = Nothing
						dx.Reset
					End if
				FSO = Nothing
			Else
				dx.Add("NOAA weather updates their information once an hour.  ")
				dx.Add("They recommend you update your information at 15 after each hour.  ")
				dx.Add("WeatherXML has been designed to only allow downloading from NOAA once every ")
				dx.Add(intmintime)
				dx.Add(" minutes.  ")
				dx.Add("It has only been ")
				dx.Add(dateDiff("n",lastran,Now))
				dx.Add(" minutes.  You may run the script to import from the existing XML file.  ")
				dx.Add("But a new XML file will not be downloaded until the allowed time.  ")
				hs.WriteLog(IName,dx.Value)
				dx.Reset
			End if
		dx = Nothing
	Catch e as Exception
		hs.WriteLog(IName,"downloadNOAAXML: " & e.Message)
	End Try
	Return sXMLFile
End Function

Function downloadWUXML(Optional ByVal sFile as String = "")
	Dim bPrimary as Boolean = False
	Dim intmintime, nDiff as Integer
	Dim dx, FSO, xf as Object
	Dim bRun, strDomain, strCodeArea, strPartnerID, strCondition, strFileName, sType, lastran, sXMLFile, sXMLCont, sFile2, dChkKey, sFileName as String
	'api.wunderground.com/api/[KEY]/FEATURE/[FEATURE]/q/[QUERY].[FORMAT]
	Try
		strPartnerID = hs.GetINISetting("Settings","WUAPI","",sINI)
		sXMLFile = "N/A"
		dx = hs.CreateStringClass
			sType=".xml"
			if lCase(sFile) = "conditions" Then
				strCondition="/FEATURE/conditions/q/"
				dx.Add("WUCondition")
				dx.Add(sType)
				strFileName=dx.Value
				dx.Reset
				dChkKey="lastranWUC"
				bRun = hs.GetINISetting("WeatherUnderground",sFile,"",sINI)
			Elseif lCase(sFile) = "alerts" Then
				strCondition="/FEATURE/alerts/q/"
				dx.Add("WUalerts")
				dx.Add(sType)
				strFileName=dx.Value
				dx.Reset
				dChkKey="lastranWUAt"
				bRun = hs.GetINISetting("WeatherUnderground",sFile,"",sINI)
			Elseif lCase(sFile) = "almanac" Then
				strCondition="/FEATURE/almanac/q/"
				dx.Add("WUalmanac")
				dx.Add(sType)
				strFileName=dx.Value
				dx.Reset
				dChkKey="lastranWUAl"
				bRun = hs.GetINISetting("WeatherUnderground",sFile,"",sINI)
			Elseif lCase(sFile) = "astronomy" Then
				strCondition="/FEATURE/astronomy/q/"
				dx.Add("WUastronomy")
				dx.Add(sType)
				strFileName=dx.Value
				dx.Reset
				dChkKey="lastranWUA"
				bRun = hs.GetINISetting("WeatherUnderground",sFile,"",sINI)
			Elseif lCase(sFile) = "forecast" Then
				strCondition="/FEATURE/forecast7day/q/"
				dx.Add("WUForecast")
				dx.Add(sType)
				strFileName=dx.Value
				dx.Reset
				dChkKey="lastranWUF"
				bRun = hs.GetINISetting("WeatherUnderground",sFile,"",sINI)
			Elseif lCase(sFile) = "history" Then
				dx.Add("/FEATURE/history_")
				dx.Add(Year(Now())-1)
				dx.Add(Month(Now()))
				dx.Add(Day(Now()))
				dx.Add("/q/")
				strCondition=dx.Value
				dx.Reset
				dx.Add("WUHistory")
				dx.Add(sType)
				strFileName=dx.Value
				dx.Reset
				dChkKey="lastranHistory"
				bRun = hs.GetINISetting("WeatherUnderground",sFile,"",sINI)
			Elseif lCase(sFile) = "radar" Then
				strCondition="/FEATURE/radar/q/"
				dx.Add("WURadar")
				dx.Add(sType)
				strFileName=dx.Value
				dx.Reset
				dChkKey="lastranWUR"
				bRun = hs.GetINISetting("WeatherUnderground",sFile,"",sINI)
			Else
				dx.Add("/FEATURE/")
				dx.Add(sFile)
				dx.Add("/q/")
				strCondition=dx.Value
				dx.Reset
				dx.Add("WU")
				dx.Add(sFile)
				dx.Add(sType)
				strFileName=dx.Value
				dx.Reset
				dx.Add("lastran")
				dx.Add(sFile)
				dChkKey= dx.Value
				dx.Reset
				bRun = hs.GetINISetting("WeatherUnderground",sFile,"",sINI)
			End if
			dx.Reset
			if hs.GetINISetting("settings","xmlSource","",sINI) = "wu" Then
				bPrimary = True
			End if
			if lCase(bRun) <> "true" AND bPrimary = False Then
				if debugMode = True Then
					dx.Add("The Weather Underground XML file for ")
					dx.Add(sFile)
					dx.Add(" has not been selected.  Please activate it on the setup page if you wish to use this information.")
					hs.WriteLog(IName,dx.Value)
				End if
				Exit Function
			End if
			strDomain = "api.wunderground.com"
			strCodeArea = "/api/"
			if len(trim(strPartnerID)) = 0 Then
				dx.Add("The Weather Underground API code (")
				dx.Add(strPartnerID)
				dx.Add(") is missing.  The XML files can not be downloaded without that information.  ")
				dx.Add("Please read the instructions on how to obtain and enter the missing information.")
				hs.WriteLog(IName,dx.Value)
				dx.Reset
				Exit Function
			End if
			lastran = hs.GetINISetting ("Settings",dChkKey,"",sINI)
			intmintime= CInt(hs.GetINISetting ("Settings","mintimewu",15,sINI))
			if IsNumeric(intmintime) Then
				if intmintime < 15 Then
					intmintime = 15
				End if
			End if
			if NOT IsDate(lastran) Then
				hs.SaveINISetting ("Settings",dChkKey,DateAdd("n",-15,Now),sINI)
				lastran = hs.GetINISetting ("Settings",dChkKey,"",sINI)
			End if
			dx.Add(hs.GetAppPath)
			dx.Add("\data\weathercom_xml\")
			dx.Add(strFileName)
			sXMLFile = dx.Value
			dx.Reset
			if debugMode = True Then
				hs.WriteLog(IName,"last run time: " & lastran)
			End if
			nDiff = DateDiff("n",lastran,Now)
			if nDiff >= intmintime Then
				dx.Add(strCodeArea)
				dx.Add(strPartnerID)
				dx.Add(strCondition)
				dx.Add(hs.GetINISetting("Settings","wulat","",sINI))
				dx.Add(",")
				dx.Add(hs.GetINISetting("Settings","wulon","",sINI))
				dx.Add(sType)
				sFileName = dx.Value
				sXMLCont = hs.GetURL (strDomain, dx.Value,FALSE,80)
				dx.Reset
				sXMLCont = replace(sXMLCont, "ISO-8859-1", "utf-8") 
				sXMLCont = replace(sXMLCont, "&deg;","")
				if debugMode = true Then
					dx.Add("Downloading the Weather Underground ")
					dx.Add(sFile)
					dx.Add(" XML file: ")
					dx.Add(strDomain)
					dx.Add(sFileName)
					hs.WriteLog(IName,dx.Value)
					dx.Reset
				End if
				FSO = CreateObject("Scripting.FileSystemObject")
					xf = FSO.CreateTextFile (sXMLFile,True)
						xf.WriteLine (sXMLCont)
						xf.Close
					xf = Nothing
					hs.SaveINISetting ("Settings",dChkKey,Now,sINI)
					sFile2 = hs.GetINISetting ("Settings","xmlweblocation","",sINI)
					if len(trim(sFile2)) > 0 Then
						dx.Add(hs.GetAPPPath)
						dx.Add("\html\")
						dx.Add(sFile2)
						dx.Add("\")
						dx.Add(strFileName)
						xf = FSO.CreateTextFile (dx.Value,True)
							xf.WriteLine (sXMLCont)
							xf.Close
						xf = Nothing
						dx.Reset
					End if
				FSO = Nothing
			Else
				dx.Add("Weather Underground (WU) allows a limited number of downloads.  ")
				dx.Add("To make sure you don't go over your limits, weatherXML will only allow download once every ")
				dx.Add(intmintime)
				dx.Add(" minutes.  It has only been ")
				dx.Add(nDiff)
				dx.Add(" minutes.  You may run the script to import from the existing XML files.  ")
				dx.Add("But new ")
				dx.Add(sFile)
				dx.Add(" XML files will not be downloaded until the allowed time.  ")
				hs.WriteLog(IName,dx.Value)
				dx.Reset
			End if
		dx = Nothing
	Catch e as exception
		hs.WriteLog(IName,"downloadWUXML: " & e.Message)
	End Try
	Return sXMLFile
End Function

Function downloadWWOXML()
	Dim intmintime as Integer
	Dim wx, FSO, xf as Object
	Dim sWWOURL, sWWODomain, sWWOlat, sWWOlon, sWWOAPI, sXMLFile, sXMLCont, sFile2, lastran as String
	sWWOlat = hs.GetINISetting("Settings","wwolat","",sINI)
	sWWOlon = hs.GetINISetting("Settings","wwolon","",sINI)
	sWWOAPI = hs.GetINISetting("Settings","WWOAPIKey","",sINI)
	if len(trim(sWWOlat)) = 0 OR len(trim(sWWOlon)) = 0 OR len(trim(sWWOAPI)) = 0 Then
		hs.WriteLog(IName,"The World Weather Online API, Latitude or Longitude is missing.  The XML file can not be downloaded without that information.  Please read the instructions on how to obtain and enter the missing information.")
		Exit Function
	End if
	wx = hs.CreateStringClass
		lastran = hs.GetINISetting("Settings","lastranDlWWO","",sINI)
		intmintime= CInt(hs.GetINISetting("Settings","mintime",15,sINI))
		if IsNumeric(intmintime) Then
			if intmintime < 15 Then
				intmintime = 15
			End if
		End if
		if NOT IsDate(lastran) Then
			hs.SaveINISetting("Settings","lastranDlWWO",DateAdd("n",-15,Now),sINI)
			lastran = hs.GetINISetting("Settings","lastranDlWWO","",sINI)
		End if
		wx.Add(hs.GetAPPPath)
		wx.Add("\data\weathercom_xml\weatherWorld.xml")
		sXMLFile = wx.Value
		wx.Reset
		if DateDiff("n",lastran,Now) >= intmintime Then
			sWWODomain = "free.worldweatheronline.com"
			wx.Add("/feed/weather.ashx?q=")
			wx.Add(sWWOlat)
			wx.Add(",")
			wx.Add(sWWOlon)
			wx.Add("&format=xml&num_of_days=5&key=")
			wx.Add(sWWOAPI)
			sXMLCont = hs.GetURL (sWWODomain, wx.Value,FALSE,80)
			wx.Reset
			if debugMode = true Then
				hs.WriteLog(IName,"Downloading the weather XML file now from worldweatheronline.com")
			End if
			FSO = CreateObject("Scripting.FileSystemObject")
				xf = FSO.CreateTextFile (sXMLFile,True)
					xf.WriteLine (sXMLCont)
					xf.Close
				xf = Nothing
				hs.SaveINISetting("Settings","lastranDlWWO",Now,sINI)
				sFile2 = hs.GetINISetting("Settings","xmlweblocation","",sINI)
				if len(trim(sFile2)) > 0 Then
					wx.Add(hs.GetAPPPath)
					wx.Add("\html\")
					wx.Add(sFile2)
					wx.Add("\weathercom.xml")
					xf = FSO.CreateTextFile (wx.Value,True)
						xf.WriteLine (sXMLCont)
						xf.Close
					xf = Nothing
					wx.Reset
				End if
			FSO = Nothing
		Else
			wx.Add("World Weather Online (WWO) requests that you do not request the same location more than once every 15 minutes.  ")
			wx.Add("WeatherXML has been designed to only allow downloading from WWO a maximum of once every ")
			wx.Add(intmintime)
			wx.Add(" minutes.  It has only been ")
			wx.Add(dateDiff("n",lastran,Now))
			wx.Add(" minutes.  You may run the script to import from the existing XML file.  ")
			wx.Add("But a new XML file will not be downloaded until the allowed time.  ")
			hs.WriteLog(IName,wx.Value)
			wx.Reset
		End if
	wx = Nothing
	Return sXMLFile
End Function

Function getFeelsLike(ByVal nTemp as Single, ByVal sWindChill as String, ByVal sHumid as String)
	Dim feelLike as Single = 0
	Try
		' Feel like
		if nTemp >= 80 Then
			if len(trim(sHumid)) > 0 Then
				feelLike = -42.379+2.04901523*nTemp+10.14333127*sHumid-0.22475541*nTemp*sHumid-6.83783*(Math.pow(10, -3))*(Math.pow(nTemp, 2))-5.481717*(Math.pow(10, -2))*(Math.pow(sHumid, 2))+1.22874*(Math.pow(10, -3))*(Math.pow(nTemp, 2))*sHumid+8.5282*(Math.pow(10, -4))*nTemp*(Math.pow(sHumid, 2))-1.99*(Math.pow(10, -6))*(Math.pow(nTemp, 2))*(Math.pow(sHumid,2))
			End if
		Else
			if len(trim(sWindChill)) > 0 Then
				if cSng(sWindChill) > 4 AND cSng(sWindChill) < 60 Then
					feelLike = Math.Ceiling(0.0817*(3.71*Math.sqrt(sWindChill)+5.81 - 0.25*sWindChill)*(nTemp-91.4) + 91.4)
				Elseif cSng(sWindChill) <= 4 Then
					feelLike = nTemp
				Elseif cSng(sWindChill) >= 60 Then
					feelLike = Math.Ceiling(0.0817*(3.71*Math.sqrt(60)+5.81 - 0.25*60)*(nTemp-91.4) + 91.4)
				End if
			End if
		End if
	Catch e as Exception
		hs.WriteLog(IName,"getFeelsLike: " & e.Message)
	End Try
	return feelLike
End Function

Sub importCondition(ByVal strXMLFile as String)
	Dim bChk as Boolean = False
	Dim bWd, bRh as Boolean
	Dim dRun as Date
	Dim x as Integer
	Dim fs, xmlfile, oNodeList, oNode, xNode, xNode2 as Object
	Dim curTemp, cBar, wcTemp, wcWind, wcHum, wkWind as String
	' Single
	Dim unitTemp, innerHeading, sValue, sValue2, sYear, sWhereFrom, sWindDir as String
	Dim feelLike, sImage, dTime, dChk, sLastUp, sDirection as String
	Try
		fs = hs.CreateStringClass
			unitTemp = hs.GetINISetting("InfoUnit","Temperature","F",sINI)
			sWhereFrom = hs.GetINISetting("settings","xmlSource","",sINI)
			' Make sure the file downloaded
			if XMLFileExists(strXMLFile) = False Then
				Exit Sub
			End if
			' Start the import from the file
			xmlfile = CreateObject("Microsoft.XMLDOM")
				xmlfile.async=false
				xmlfile.load(strXMLFile)
				hs.SaveINISetting("Debug","ErrorCodeCondition",xmlfile.parseError.errorcode,sINI)
				if xmlfile.parseError.errorcode <> 0 Then
					fs.Add("There was an error with the XML file.  Error Reason: ")
					fs.Add(xmlfile.parseError.reason)
					hs.WriteLog(IName,fs.Value)
					fs.Reset
					dRun = dRun.addMinutes(-30)
					hs.SaveINISetting("Settings","lastranWUC",dRun,sINI)
					hs.SaveINISetting("Debug","ErrorReasonCondition",xmlfile.parseError.reason,sINI)
					hs.SaveINISetting("Debug","ErrorTimeCondition",Trim(Now()),sINI)
				End if
				if xmlfile.parseError.errorcode = 0 Then
					oNodeList = xmlfile.selectNodes("response/current_observation")
						oNode = oNodeList.nextNode
							if sWhereFrom = "wu" OR sWhereFrom = "wwo" Then
								xNode = oNode.selectSingleNode("observation_time")
								if NOT xNode Is Nothing Then
									if sWhereFrom = "wu" Then
										Try
											sValue = oNode.selectSingleNode("observation_time").text
											sValue = replace(sValue,"Laatst ververst op ","")
											fs.Add(" ")
											fs.Add(Year(Now))
											fs.Add(",")
											sLastUp = replace(sValue,",",fs.Value)
											fs.Reset
											hs.SaveINISetting ("Location","TimeChecked",sLastUp,sINI)
											if debugMode = True Then
												hs.WriteLog(IName,"tijd: " & sValue)
											End if
											' Last Updated
											setDeviceUpdated(sLastUp,sLastUp)
										Catch ex as Exception
											hs.WriteLog(IName,"Error with observation time: " & ex.Message)
										End Try
										Try
											' Current Temp
											if unitTemp = "F" Then
												curTemp = oNode.selectSingleNode("temp_f").Text
											Else
												curTemp = oNode.selectSingleNode("temp_c").Text
											End if
											' Check the temp for daily hi low values
											setDailyHiLow(cInt(curTemp))
										Catch ex as Exception
											hs.WriteLog(IName,"Error with current temp: " & ex.Message)
										End Try
										Try
											' Humidity
											xNode = oNode.selectSingleNode("relative_humidity")
											if Not xNode Is Nothing Then
												sValue = oNode.selectSingleNode("relative_humidity").Text
												wcHum = replace(sValue,"%","")
												setDeviceHumidity(wcHum)
												bRh = True
											Else
												setDeviceHumidity("")
											End if
										Catch ex as Exception
											hs.WriteLog(IName,"Error with humidity: " & ex.Message)
										End Try
									End if
									' Wind Gust
									if debugMode = True Then
										hs.WriteLog(IName,"Getting Wind Information")
									End if
									Try
										xNode = oNode.selectSingleNode("wind_gust_mph")
										if Not xNode Is Nothing Then
											wkWind = oNode.selectSingleNode("wind_gust_mph").text
											if hs.GetINISetting("InfoUnit","speedUnit","mph",sINI) = "kmph" Then
												if isNumeric(oNode.selectSingleNode("wind_gust_mph").text) Then
													wKWind = convertMPH(oNode.selectSingleNode("wind_gust_mph").text)
												End if
											End if
											setDeviceWindGust(wkWind)
										Else
											setDeviceWindGust("")
										End if
									Catch ex as Exception
										hs.WriteLog(IName,"Error with wind gust: " & ex.Message)
									End Try
									if sWhereFrom = "wu" Then
										Try
											' Wind Degrees
											xNode = oNode.selectSingleNode("wind_degrees")
											if Not xNode Is Nothing Then
												setDeviceWindDeg(oNode.selectSingleNode("wind_degrees").text)
											Else
												setDeviceWindDeg("")
											End if
										Catch ex as Exception
											hs.WriteLog(IName,"Error with wind degrees: " & ex.Message)
										End Try
										Try
											' Wind Direction
											xNode = oNode.selectSingleNode("wind_dir")
											if Not xNode Is Nothing Then
												sWindDir = hs.RunEx("AZ_weatherXML_web.vb","windDirImage",oNode.selectSingleNode("wind_dir").text,True)
												setDeviceWindDir(sWindDir)
											Else
												setDeviceWindDir("")
											End if
										Catch ex as Exception
											hs.WriteLog(IName,"Error with wind direction: " & ex.Message)
										End Try
										Try
											' Wind Speed
											xNode = oNode.selectSingleNode("wind_mph")
											if Not xNode Is Nothing Then
												wcWind = oNode.selectSingleNode("wind_mph").text
												if hs.GetINISetting("InfoUnit","speedUnit","mph",sINI) = "kmph" Then
													wKWind = convertMPH(wcWind)
												Else 
													wkWind = wcWind
												End if
												setDeviceWindSpeed(wkWind)
												bWd = True
											Else
												setDeviceWindSpeed("")
											End if
										Catch ex as Exception
											hs.WriteLog(IName,"Error with wind speed: " & ex.Message)
										End Try
										Try
											' Feel like
											if debugMode = True Then
												hs.WriteLog(IName,"Getting Feels Like Information")
											End if
											feelLike = "N/A"
											if uCase(unitTemp) = "F" Then
												xNode = oNode.selectSingleNode("windchill_f")
												xNode2 = oNode.selectSingleNode("heat_index_f")
											Else
												xNode = oNode.selectSingleNode("windchill_c")
												xNode2 = oNode.selectSingleNode("heat_index_c")
											End if
											if xNode Is Nothing AND xNode2 Is Nothing Then
												bChk = True
											Else
												bChk = true
												if curTemp > 80 Then
													if Not xNode2 Is Nothing THen
														if uCase(unitTemp) = "F" Then
															feelLike = oNode.selectSingleNode("heat_index_f").text
															if isNumeric(feelLike) Then
																bChk = false
															End if
														Else
															feelLike = oNode.selectSingleNode("heat_index_c").text
															if isNumeric(feelLike) Then
																bChk = false
															End if
														End if
													End if
												Else
													if Not xNode Is Nothing Then
														if uCase(unitTemp) = "F" Then
															feelLike = oNode.selectSingleNode("windchill_f").text
															if isNumeric(feelLike) Then
																bChk = false
															End if
														Else
															feelLike = oNode.selectSingleNode("windchill_c").text
															if isNumeric(feelLike) Then
																bChk = false
															End if
														End if
													End if
												End if
											End if
											if bChk = true Then
												if uCase(unitTemp) = "F" Then
													wcTemp = curTemp 
												Else
													wcTemp = curTemp*(9/5)+32
												End if
												feelLike = getFeelsLike(wcTemp,wcWind,wcHum)
												if isNumeric(feelLike) Then
													if uCase(unitTemp) <> "F" Then
														feelLike = (feelLike-32)/9*5
													End if
												End if
											End if
											' Feels Like
											setDeviceLike(feelLike)
										Catch ex as Exception
											hs.WriteLog(IName,"Error with feels lik: " & ex.Message)
										End Try
										Try
											' Current Temperature
											if debugMode = True Then
												hs.WriteLog(IName,"Getting Temperature Information")
											End if
											setDeviceTemp(curTemp,feelLike)
											' Condition & Condition Icon
											sImage = oNode.selectSingleNode("icon_url").Text
											setDeviceCondition(oNode.selectSingleNode("weather").Text,sImage)
											' Condition Image
											setDeviceCondImage()
										Catch ex as Exception
											hs.WriteLog(IName,"Error with condition image: " & ex.Message)
										End Try
									End if
									Try
										' Dewpoint
										if unitTemp = "F" Then
											setDeviceDoTheDew(oNode.selectSingleNode("dewpoint_f").Text)
										Else
											setDeviceDoTheDew(oNode.selectSingleNode("dewpoint_c").Text)
										End if
									Catch ex as Exception
										hs.WriteLog(IName,"Error with dewpoint: " & ex.Message)
									End Try
									if sWhereFrom = "wu" Then
										Try
											' Barometer
											if hs.GetINISetting ("InfoUnit","pressureUnit","i",sINI) = "i" Then
												xNode = oNode.selectSingleNode("pressure_in")
											Else
												xNode = oNode.selectSingleNode("pressure_mb")
											End if
											dTime = oNode.selectSingleNode("observation_time_rfc822").text
											dChk = hs.GetINISetting("WeatherInfo","BarometerTime","",sINI)
											if Not xNode Is Nothing Then
												if hs.GetINISetting ("InfoUnit","pressureUnit","i",sINI) = "i" Then
													cBar = oNode.selectSingleNode("pressure_in").text
												Else
													cBar = oNode.selectSingleNode("pressure_mb").text
												End if
												xNode=oNode.selectSingleNode("pressure_trend")
												if xNode Is Nothing Then
													if trim(dTime) <> trim(dChk) Then
														setDeviceBarometer(cBar,dTime)
													Else
														setDeviceBarometer(cBar)
													End if
												Else
													sDirection = oNode.selectSingleNode("pressure_trend").text
													setDeviceBarometer(cBar,"1",sDirection)
												End if
											Else
												setDeviceBarometer("","")
											End if
										Catch ex as Exception
											hs.WriteLog(IName,"Error with barometer: " & ex.Message)
										End Try
										Try
											' Visibility
											if hs.GetINISetting("InfoUnit","speedUnit","mph",sINI) = "kmph" Then
												xNode = oNode.selectSingleNode("visibility_km")
											Else
												xNode = oNode.selectSingleNode("visibility_mi")
											End if
											if Not xNode Is Nothing Then
												if hs.GetINISetting("InfoUnit","distanceUnit","m",sINI) = "km" Then
													setDeviceVisibility(oNode.selectSingleNode("visibility_km").Text)
												Else
													setDeviceVisibility(oNode.selectSingleNode("visibility_mi").Text)
												End if
											Else
												setDeviceVisibility("")
											End if
										Catch ex as Exception
											hs.WriteLog(IName,"Error with visibility: " & ex.Message)
										End Try
									End if
								End if
							End if
					oNodeList = Nothing
				End if
			xmlfile = Nothing
		fs = Nothing
	Catch e as Exception
		hs.WriteLog(IName,"importCondition: " & e.message)
	End Try	
End Sub

Sub resetHiLowValues(Optional ByVal sParm as String = "")
	Dim dRanDate as String
	' Call the reset function if ran the first time today and start the daily values over
	dRanDate=hs.GetINISetting ("Settings","RanDate","",sINI)
	if IsDate(dRanDate) Then
		if Day(dRanDate) <> Day(Now) Then
			if debugMode = true Then
				hs.WriteLog(IName,"Reseting the daily high and low values.")
			End if
			hs.SaveINISetting ("HighLowData","Low_Temp","",sINI)
			hs.SaveINISetting ("HighLowData","High_Temp","",sINI)
			hs.SaveINISetting ("Settings","RanDate",Now(),sINI)
		End if
	Else
		hs.SaveINISetting ("Settings","RanDate",Now(),sINI)
	End if
End Sub

Sub saveConditionIcon(ByVal sImage as String)
	Dim pos1 as Integer
	Dim ci as Object
	Dim sDomain, sFile, sFileName, sSaveTo, sReverse as string
	Try
		ci = hs.CreateStringClass
			sImage = hs.GetINISetting("WeatherInfo","ConditionIcon","",sINI)
			sImage = replace(sImage,"http://","")
			pos1 = inStr(sImage,"/")-1
			sDomain = left(sImage,pos1)
			sFile = replace(sImage,sDomain,"")

			sReverse = hs.RunEx("AZ_weatherXML_wu.vb","ReverseString",sFile,True)
			pos1 = inStr(sReverse,"/")-1
			sFileName = left(sReverse,pos1)
			sFileName = hs.RunEx("AZ_weatherXML_wu.vb","ReverseString",sFileName,True)

			ci.Add(hs.GetAppPath)
			ci.Add("\html\Images\weathericons\condition\curcond.jpg")
			sSaveTo = ci.Value
			ci.Reset
			if debugMode = True Then
				ci.Add("Save condition image to: ")
				ci.Add(sSaveTo)
				hs.WriteLog(IName,ci.Value)
				ci.Reset
			End if
			hs.GetURLImage(sDomain,sFile,True,80,sSaveTo)
		
			ci.Add(hs.GetAppPath)
			ci.Add("\html\Images\weathericons\condition\")
			ci.Add(sFileName)
			sSaveTo = ci.Value
			ci.Reset
			if debugMode = True Then
				ci.Add("Save condition image to: ")
				ci.Add(sSaveTo)
				hs.WriteLog(IName,ci.Value)
				ci.Reset
			End if
			hs.SaveINISetting("WeatherInfo","ConditionIconName",sFileName,sINI)
			hs.GetURLImage(sDomain,sFile,True,80,sSaveTo)
			
			if hs.GetINISetting("Settings","runMCSTemp","False",sINI) = "True" Then
				ci.Add(hs.GetAppPath)
				ci.Add("\html\Images\weather\")
				ci.Add(sFileName)
				sSaveTo = ci.Value
				ci.Reset
				if debugMode = True Then
					ci.Add("Save condition image to: ")
					ci.Add(sSaveTo)
					hs.WriteLog(IName,ci.Value)
					ci.Reset
				End if
				hs.GetURLImage(sDomain,sFile,True,80,sSaveTo)			
			End if
		ci = Nothing
	Catch e as Exception
		hs.WriteLog(IName,"saveCondtionIcon: " & e.Message)
	End Try
End Sub

Sub setDailyHiLow(ByVal node1 as String)
	Dim sHL as Object
	Dim sOldTemp, devHiTemp, devLowTemp as String
	sOldTemp = hs.GetINISetting ("HighLowData","High_Temp","",sINI)
	devHiTemp = hs.GetINISetting ("Settings","devHiTemp","",sINI)
	devlowTemp = hs.GetINISetting ("Settings","devLowTemp","",sINI)
	sHL = hs.CreateStringClass
		if node1 = "setDevice" Then
			sHL.Add (hs.GetINISetting("Settings","TableStartCode","",sINI))
			if UseIcons = "True" Then
				sHL.Add("<img src='\images\weathericons\thermos\")
				sHL.Add(cInt(hs.GetINISetting("HighLowData","High_Temp","",sINI)))
				sHL.Add(".gif' width='36' height='77' align='middle'>")
			End if
			sHL.Add(hs.GetINISetting("Settings","TableMidCode","",sINI))
			if useHeadings = True Then
				sHL.Add("<span style=""")
				sHL.Add(hs.GetINISetting ("Settings","useHeadingsStyle","",sINI))
				sHL.Add(""">")
				sHL.Add(hs.GetINISetting("Language","temperatureHigh","Hoogste temperatuur voor vandaag",sINI))
				sHL.Add(":</span><br/>")
			End if
			sHL.Add(hs.GetINISetting("HighLowData","High_Temp","",sINI))
			sHL.Add("&deg; ")
			sHL.Add(hs.GetINISetting("InfoUnit","Temperature","",sINI))
			sHL.Add(". ")
			sHL.Add(hs.GetINISetting("Settings","TableEndCode","",sINI))
			hs.SetDeviceString(devHiTemp,sHL.Value,True)
			If IsNumeric(hs.GetINISetting("HighLowData","High_Temp","",sINI)) Then
				hs.SetDeviceValue(devHiTemp,CInt(hs.GetINISetting("HighLowData","High_Temp","",sINI)))
			End if
			sHL.Reset
			sHL.Add (hs.GetINISetting("Settings","TableStartCode","",sINI))
			if UseIcons = "True" Then
				sHL.Add("<img src='\images\weathericons\thermos\")
				sHL.Add(cInt(hs.GetINISetting("HighLowData","Low_Temp","",sINI)))
				sHL.Add(".gif' width='36' height='77' align='middle'>")
			End if
			sHL.Add(hs.GetINISetting("Settings","TableMidCode","",sINI))
			if useHeadings = True Then
				sHL.Add("<span style=""")
				sHL.Add(hs.GetINISetting ("Settings","useHeadingsStyle","",sINI))
				sHL.Add(""">")
				sHL.Add(hs.GetINISetting("Language","temperatureLow","Laagste temperatuur voor vandaag",sINI))
				sHL.Add(":</span><br/>")
			End if
			sHL.Add(hs.GetINISetting ("HighLowData","Low_Temp","",sINI))
			sHL.Add("&deg; ")
			sHL.Add(hs.GetINISetting("InfoUnit","Temperature","",sINI))
			sHL.Add(". ")
			sHL.Add(hs.GetINISetting("Settings","TableEndCode","",sINI))
			hs.SetDeviceString(devLowTemp,sHL.Value,True)
			If IsNumeric(hs.GetINISetting("HighLowData","Low_Temp","",sINI)) Then
				hs.SetDeviceValue(devLowTemp,CInt(hs.GetINISetting("HighLowData","Low_Temp","",sINI)))
			End if
			sHL.Reset		
		Else
			if IsNumeric(sOldTemp) Then
				if CInt(sOldTemp) < CInt(node1) Then
					hs.SaveINISetting ("HighLowData","High_Temp",cInt(node1),sINI)
					hs.SaveINISetting("HighLowData","High_Temp_Time",trim(Now()),sINI)
					sHL.Add (sTableStartCode)
					if UseIcons = "True" Then
						sHL.Add("<img src='\images\weathericons\thermos\")
						sHL.Add(cInt(node1))
						sHL.Add(".gif' width='36' height='77' align='middle'>")
					End if
					sHL.Add(sTableMidCode)
					if useHeadings = True Then
						sHL.Add(useHeadingStyle)
						sHL.Add(hs.GetINISetting("Language","temperatureHigh","Hoogste temperatuur vandaag",sINI))
						sHL.Add(":</span><br/>")
					End if
					sHL.Add(node1)
					sHL.Add("&deg; ")
					sHL.Add(hs.GetINISetting("InfoUnit","Temperature","",sINI))
					sHL.Add(". ")
					sHL.Add(sTableEndCode)
					hs.SetDeviceString(devHiTemp,sHL.Value,True)
					If IsNumeric(node1) Then
						hs.SetDeviceValue(devHiTemp,CInt(node1))
					End if
					sHL.Reset
				End if
			Else
				hs.SaveINISetting ("HighLowData","High_Temp",cInt(node1),sINI)
				hs.SaveINISetting("HighLowData","High_Temp_Time",trim(Now()),sINI)
				sHL.Add (sTableStartCode)
				if UseIcons = "True" Then
					sHL.Add("<img src='\images\weathericons\thermos\")
					sHL.Add(cInt(node1))
					sHL.Add(".gif' width='36' height='77' align='middle'>")
				End if
				sHL.Add(sTableMidCode)
				if useHeadings = True Then
					sHL.Add(useHeadingStyle)
					sHL.Add(hs.GetINISetting("Language","temperatureHigh","Hoogste temperatuur vandaag",sINI))
					sHL.Add(":</span><br/>")
				End if
				sHL.Add(node1)
				sHL.Add("&deg; ")
				sHL.Add(hs.GetINISetting("InfoUnit","Temperature","",sINI))
				sHL.Add(". ")
				sHL.Add(sTableEndCode)
				hs.SetDeviceString(devHiTemp,sHL.Value,True)
				If IsNumeric(node1) Then
					hs.SetDeviceValue(devHiTemp,CInt(node1))
				End if
				sHL.Reset
			End if
			sOldTemp = hs.GetINISetting ("HighLowData","Low_Temp","",sINI)
			if IsNumeric(sOldTemp) Then
				if CInt(sOldTemp) > CInt(node1) Then
					hs.SaveINISetting ("HighLowData","Low_Temp",node1,sINI)
					hs.SaveINISetting("HighLowData","Low_Temp_Time",trim(Now()),sINI)
					sHL.Add (sTableStartCode)
					if UseIcons = "True" Then
						sHL.Add("<img src='\images\weathericons\thermos\")
						sHL.Add(cInt(node1))
						sHL.Add(".gif' width='36' height='77' align='middle'>")
					End if
					sHL.Add(sTableMidCode)
					if useHeadings = True Then
						sHL.Add(useHeadingStyle)
						sHL.Add(hs.GetINISetting("Language","temperatureLow","Laagste temperatuur vandaag",sINI))
						sHL.Add(":</span><br/>")
					End if
					sHL.Add(node1)
					sHL.Add("&deg; ")
					sHL.Add(hs.GetINISetting("InfoUnit","Temperature","",sINI))
					sHL.Add(". ")
					sHL.Add(sTableEndCode)
					hs.SetDeviceString(devLowTemp,sHL.Value,True)
					If IsNumeric(node1) Then
						hs.SetDeviceValue(devLowTemp,CInt(node1))
					End if
					sHL.Reset
				End if
			Else
				hs.SaveINISetting ("HighLowData","Low_Temp",node1,sINI)
				hs.SaveINISetting("HighLowData","Low_Temp_Time",trim(Now()),sINI)
				sHL.Add (sTableStartCode)
				if UseIcons = "True" Then
					sHL.Add("<img src='\images\weathericons\thermos\")
					sHL.Add(cInt(node1))
					sHL.Add(".gif' width='36' height='77' align='middle'>")
				End if
				sHL.Add(sTableMidCode)
				if useHeadings = True Then
					sHL.Add(useHeadingStyle)
					sHL.Add(hs.GetINISetting("Language","temperatureLow","Laagste temperatuur vandaag",sINI))
					sHL.Add(":</span><br/>")
				End if
				sHL.Add(node1)
				sHL.Add("&deg; ")
				sHL.Add(hs.GetINISetting("InfoUnit","Temperature","",sINI))
				sHL.Add(". ")
				sHL.Add(sTableEndCode)
				hs.SetDeviceString(devLowTemp,sHL.Value,True)
				If IsNumeric(node1) Then
					hs.SetDeviceValue(devLowTemp,CInt(node1))
				End if
				sHL.Reset
			End if
		End if
	sHL = Nothing
End Sub

Sub setDeviceBarometer(ByVal node1 as String,Optional ByVal dChange as String = "",Optional ByVal node2 as String = "")
	Dim fs as Object
	Dim devBarometer, devBarometerDir, sBarOld as String
	Try
		sBarOld = hs.GetINISetting("WeatherInfo","Barometer",node1,sINI)
		if len(trim(node2)) = 0 Then
			if sBarOld < node1 Then
				node2 = "rising"
			Elseif sBarOld > node1 Then
				node2 = "falling"
			Else 
				node2 = "steady"
			End if
		Else
			if node2 = "0" Then
				node2 = "steady"
			Elseif node2 = "+" Then
				node2 = "rising"
			Else
				node2 = "falling"
			End if
		End if
		hs.SaveINISetting ("WeatherInfo","Barometer",node1,sINI)
		hs.SaveINISetting ("WeatherInfo","BarometerDir",node2,sINI)
		if len(trim(dChange)) > 0 Then
			hs.SaveINISetting("WeatherInfo","BarometerTime",dChange,sINI)
		End if
		devBarometer = hs.GetINISetting ("Settings","devBarometer","",sINI)
		devBarometerDir = hs.GetINISetting ("Settings","devBarometerDir","",sINI)
		if len(trim(devBarometer)) = 0 Then
			hs.SetDeviceString(devBarometer,"N/A",True)
			hs.SetDeviceString(devBarometerDir,"N/A",True)
		Else
			fs = hs.CreateStringClass
				fs.Add(sTableStartCode)
				if UseIcons = True Then
					fs.Add("<img src='\images\weathericons\barometric\")
					fs.Add(node2)
					fs.Add(".gif' align='middle'>")
				End if
				fs.Add(sTableMidCode)
				if useHeadings = True Then
					fs.Add(useHeadingStyle)
					fs.Add(hs.GetINISetting("Language","barometer","Barometer",sINI))
					fs.Add(":</span><br/>")
				End if
				fs.Add(node1)
				fs.Add(" ")
				fs.Add(hs.GetINISetting("InfoUnit","Pressure","inches",sINI))
				if len(trim(dChange)) > 0 Then
					fs.Add(" en ")
					fs.Add(node2)
				End if
				fs.Add(sTableEndCode)
				hs.SetDeviceString(devBarometer,fs.Value,True)
				if IsNumeric(node1) Then
					hs.SetDeviceValue(devBarometer,node1)
				Else
					hs.SetDeviceValue(devBarometer,0)
				End if
				fs.Reset
	'			if len(trim(dChange)) > 0 Then
	'				if len(trim(devBarometerDir)) > 0 Then
						fs.Add(sTableStartCode)
						if UseIcons = True Then
							fs.Add("<img src='\images\weathericons\barometric\")
							fs.Add(node2)
							fs.Add(".gif' align='middle'>")
						End if
						fs.Add(sTableMidCode)
						if useHeadings = True Then
							fs.Add(useHeadingStyle)
							fs.Add(hs.GetINISetting("Language","barometerDirection","Barometer richting",sINI))
							fs.Add(":</span><br/>")
						End if
						if node2 = "steady" Then
							fs.Add("Standvast")
						Elseif node2 = "rising" Then
							fs.Add("Stijgende")
						Elseif node2 = "falling" Then
							fs.Add("Dalende")
						End if
						fs.Add(sTableEndCode)
						hs.SetDeviceString(devBarometerDir,fs.Value,True)
						if node2 = "steady" Then
							hs.SetDeviceValue(devBarometerDir,0)
						Elseif node2 = "rising" Then
							hs.SetDeviceValue(devBarometerDir,2)
						Elseif node2 = "falling" Then
							hs.SetDeviceValue(devBarometerDir,1)
						End if
						fs.Reset
	'				End if
	'			End if
			fs = Nothing
		End if
	Catch e as Exception
		hs.WriteLog(IName,"setDeviceBarometer" & e.Message)
	End Try
End Sub

Sub setDeviceCondImage(Optional ByVal node1 as String="")
    Dim fs, FSO, xf as Object
	Dim sFile, sImageCode, sCont as String
	sImageCode = hs.GetINISetting("WeatherInfo","ConditionIcon", "", sINI)
	if len(trim(sImageCode)) > 0 Then
		fs = hs.CreateStringClass
			fs.Add(hs.GetAppPath)
			fs.Add("/html/weathercom_xml/weathercondition.js")
		   	sFile = fs.Value
			fs.Reset
			fs.Add("newImage=""&nbsp;<img height='18' align='absmiddle' border='0' src='/Images/weathericons/condition/curcond.jpg'> ")
			fs.Add(hs.GetINISetting("WeatherInfo","CurrentTemp","",sINI))
			fs.Add("&deg; &nbsp; &nbsp;")
			fs.Add("<b>Sunrise:</b> ")
			fs.Add(hs.SunRise)
			fs.Add("""")
			sCont = fs.Value
			fs.Reset
			FSO = CreateObject("Scripting.FileSystemObject")
				xf = FSO.CreateTextFile (sFile,True)
					xf.WriteLine(sCont)
					xf.Close()
				xf = Nothing
			FSO = Nothing
		fs = Nothing
	End if
End Sub

Sub setDeviceCondition(ByVal node1 as String,ByVal node2 as String)
	Dim fs as Object
	Dim devCondition, sIconName as String
	' Condition & Icon
	hs.SaveINISetting("WeatherInfo","Condition",node1,sINI)
	hs.SaveINISetting("WeatherInfo","ConditionIcon",node2,sINI)
	devCondition = hs.GetINISetting ("Settings","devCondition","",sINI)
	if len(trim(devCondition)) > 0 Then
		fs = hs.CreateStringClass
			fs.Add(sTableStartCode)
			if UseIcons = True Then
				fs.Add("<img src='/Images/weathericons/condition/")
				sIconName = hs.RunEx("AZ_weatherXML_wu.vb","saveIcon",node2,True)
				fs.Add(sIconName)
				fs.Add("' style=""height:")
				fs.Add(hs.GetINISetting("settings","imagesize","64",sINI))
				fs.Add(""" alt=""")
				fs.Add(node1)
				fs.Add(""" align='middle'>")
			End if
			fs.Add(sTableMidCode)
			if useHeadings = True Then
				fs.Add(useHeadingStyle)
				fs.Add(hs.GetINISetting("Language","currentCondition","Huidige conditie",sINI))
				fs.Add(":</span><br/>")
			End if
			fs.Add(hs.GetINISetting("Language Conditions",node1,node1,sINI))
			fs.Add(sTableEndCode)
			hs.SetDeviceString(devCondition,fs.Value,True)
			fs.Reset
		fs=Nothing
	End if
	if len(trim(node2)) > 0 Then
		saveConditionIcon(node2)
	End if
End Sub

Sub setDeviceDoTheDew(ByVal node1 As String)
	Dim fs as Object
	Dim devDewpoint, dewPointImage, sURL as String
	if isNumeric(node1) Then
		node1 = cInt(node1)
	End if
	hs.SaveINISetting ("WeatherInfo","Dewpoint",node1,sINI)
	devDewpoint = hs.GetINISetting ("Settings","devDewpoint","",sINI)
	dewPointImage = hs.GetINISetting("Settings","dewpointImage","",sINI)
	if len(trim(devDewpoint)) > 0 Then
		fs = hs.CreateStringClass
			If len(trim(node1)) = 0 Then
				if useHeadings = True Then
					fs.Add(useHeadingStyle)
					fs.Add(hs.GetINISetting("Language","dewpoint","Dauwpunt",sINI))
					fs.Add(":</span><br/>")
				End if
				fs.Add("N/A")
				hs.SetDeviceString(devDewpoint,fs.Value,True)
				fs.Reset
			Else
				fs.Add("image")
				fs.Add(dewPointImage)
				sURL = hs.GetINISetting("Maps",fs.Value,"",sINI)
				fs.Reset
				fs.Add(sTableStartCode)
				if UseIcons = True Then
					if len(trim(sURL)) > 0 Then
						fs.Add("<a href='#' onClick=""window.open('")
						fs.Add(sURL)   
						fs.Add("','newWnd','width=720,height=486,toolbar=1,status=1,scrollbars=1,resizable=1')"">")
						fs.Add("<img src='\images\weathericons\dewpoint\t")
						fs.Add(node1)
						fs.Add(".gif' width='20' height='20' align='middle'>")
					End if
				End if
				fs.Add(sTableMidCode)
				if useHeadings = True Then
					fs.Add(useHeadingStyle)
					fs.Add(hs.GetINISetting("Language","dewpoint","Dauwpunt",sINI))
					fs.Add(":</span><br/>")
				End if
				fs.Add(node1)
				fs.Add("&deg; ")
				fs.Add(hs.GetINISetting("InfoUnit","Temperature","",sINI))
				fs.Add(sTableEndCode)
				hs.SetDeviceString(devDewpoint,fs.Value,True)
				If IsNumeric(node1) Then
					hs.SetDeviceValue(devDewpoint,CInt(node1))
				End if
				fs.Reset
			End if
		fs = Nothing
	End if
End Sub

Sub setDeviceForecast(Optional ByVal nDays as Integer = 10)
	Dim aParts as Array
	Dim bToday, b7th as Boolean	
	Dim x, y, nPrec as Integer
	Dim rs, fi as Object
	Dim sText, sPeriod, sForecast, sCarry, sMarS, sMarE, fDev as String
	Try
		if UseMarquee = "True" Then
			sMarS = " * "
			sMarE = " "
		Else
			sMarS = "<li>"
			sMarE = "</li>"
		End if
		if debugMode = True Then
			hs.WriteLog(IName,"Start forecast devices")
		End if
		rs = hs.CreateStringClass ' Build the 3 day forecast string
			fi = hs.CreateStringClass ' Build int ini key
				if UseMarquee = True Then
					rs.Add("<marquee behavior=""scroll"" align=""left"" direction=""left"">")
				Else
					rs.Add("<ul>")
				End if
				fi.Reset
				y = 0
				bToday = false
				b7th = false
				hs.Runex("AZ_weatherXML_wu.vb","setDeviceForecastClear","",True)
				For x = 1 to 15
					fi.Add("ExtForecast")
					fi.Add(x)
					sText = hs.GetINISetting ("WeatherCom_ExtForecast",fi.Value,"",sINI)
					fi.Reset
					if len(trim(sText)) > 0 Then
						if y > 0 AND y < 8 Then
							rs.Add(sMarS)
							rs.Add(trim(sText))
							rs.Add(sMarE)
						End if
						aParts=split(sText,":")
						sPeriod = lCase(trim(aParts(0)))
						sForecast = aParts(1)
						if sPeriod = "vandaag" Then
							fDev=hs.GetINISetting("Settings","forecastToday","",sINI)
							if len(trim(fDev)) > 0 Then
								hs.SetDeviceString(fDev,trim(sForecast),true)
							End if	
							y = 1
							bToday = true
						Elseif sPeriod = "vannacht" Then
							fDev = hs.GetINISetting ("Settings","forecastTonight","",sINI)
							if len(trim(fDev)) > 0 Then
								hs.SetDeviceString(fDev,trim(sForecast),True)
							End if
							y = 2
						Else
							if y = 2 Then
								fDev=hs.GetINISetting("Settings","forecastTomorrow","",sINI)
								if len(trim(fDev)) > 0 Then
									hs.SetDeviceString(fDev,trim(sForecast),true)
								End if
								y = y + 1
							Elseif y = 3 Then
								fDev = hs.GetINISetting ("Settings","forecastTomorrowNight","",sINI)
								if len(trim(fDev)) > 0 Then
									hs.SetDeviceString(fDev,sForecast,True)
								End if
								y = y + 1
							Elseif y = 4 Then
								sCarry = sText
								y = y + 1
							Elseif y = 5 Then
								fDev = hs.GetINISetting ("Settings","forecast2Day","",sINI)
								if len(trim(fDev)) > 0 Then
									if len(trim(sCarry)) > 0 Then
										fi.Add(sCarry)
										fi.Add("<br/>")
										fi.Add(sText)
										sForecast = fi.Value
										fi.Reset
										sCarry=""
									End if
									hs.SetDeviceString(fDev,sForecast,True)
								End if
								y = y + 1
							Elseif y = 6 Then
								sCarry = sText
								y = y + 1
							Elseif y = 7 Then
								fDev = hs.GetINISetting ("Settings","forecast3Day","",sINI)
								if len(trim(fDev)) > 0 Then
									if len(trim(sCarry)) > 0 Then
										fi.Add(sCarry)
										fi.Add("<br/>")
										fi.Add(sText)
										sForecast = fi.Value
										fi.Reset
										sCarry=""
									End if
									hs.SetDeviceString(fDev,sForecast,True)
								End if
								y = y + 1
							Elseif y = 8 Then
								sCarry = sText
								y = y + 1
							Elseif y = 9 Then
								fDev = hs.GetINISetting ("Settings","forecast4Day","",sINI)
								if len(trim(fDev)) > 0 Then
									if len(trim(sCarry)) > 0 Then
										fi.Add(sCarry)
										fi.Add("<br/>")
										fi.Add(sText)
										sForecast = fi.Value
										fi.Reset
										sCarry=""
									End if
									hs.SetDeviceString(fDev,sForecast,True)
								End if
								y = y + 1
							Elseif y = 10 Then
								sCarry = sText
								y = y + 1
							Elseif y = 11 Then
								fDev = hs.GetINISetting ("Settings","forecast5Day","",sINI)
								if len(trim(fDev)) > 0 Then
									if len(trim(sCarry)) > 0 Then
										fi.Add(sCarry)
										fi.Add("<br/>")
										fi.Add(sText)
										sForecast = fi.Value
										fi.Reset
										sCarry=""
									End if
									hs.SetDeviceString(fDev,sForecast,True)
								End if
								y = y + 1
							Elseif y = 12 Then
								sCarry = sText
								y = y + 1
								fDev = hs.GetINISetting ("Settings","forecast6Day","",sINI)
								if len(trim(fDev)) > 0 Then
									hs.SetDeviceString(fDev,sText,True)
								End if
							Elseif y = 13 Then
								fDev = hs.GetINISetting ("Settings","forecast6Day","",sINI)
								if len(trim(fDev)) > 0 Then
									if len(trim(sCarry)) > 0 Then
										fi.Add(sCarry)
										fi.Add("<br/>")
										fi.Add(sText)
										sForecast = fi.Value
										fi.Reset
										sCarry=""
									End if
									hs.SetDeviceString(fDev,sForecast,True)
								End if
								y = y + 1
							Elseif y = 14 Then
								sCarry = sText
								y = y + 1
								fDev = hs.GetINISetting ("Settings","forecast7Day","",sINI)
								if len(trim(fDev)) > 0 Then
									hs.SetDeviceString(fDev,sText,True)
								End if							
								b7th = true
							Elseif y = 15 Then
								fDev = hs.GetINISetting ("Settings","forecast7Day","",sINI)
								if len(trim(fDev)) > 0 Then
									if len(trim(sCarry)) > 0 Then
										fi.Add(sCarry)
										fi.Add("<br/>")
										fi.Add(sText)
										sForecast = fi.Value
										fi.Reset
										sCarry=""
									End if
									hs.SetDeviceString(fDev,sForecast,True)
								End if							
								b7th = true
							End if
						End if
					End if
				Next
				if UseMarquee = True Then
					rs.Add("</marquee>")
				Else
					rs.Add("</ul>")
				End if
				fDev = hs.GetINISetting ("Settings","devForecast","",sINI)
				if len(trim(fDev)) > 0 Then
					hs.SetDeviceString(fDev,trim(rs.Value),True)
				End if
				if bToday = false Then
					fDev=hs.GetINISetting("Settings","forecastToday","",sINI)
					if len(trim(fDev)) > 0 Then
						hs.SetDeviceString(fDev,"",true)
						hs.SetDeviceStatus(fDev,3)
					End if	
				End if
				if b7th = false Then
					fDev = hs.GetINISetting ("Settings","forecast7Day","",sINI)
					if len(trim(fDev)) > 0 Then
						hs.SetDeviceString(fDev,"",True)
						hs.SetDeviceStatus(fDev,3)
					End if							
				End if
			fi = Nothing
		rs = Nothing
	Catch e as Exception
		hs.WriteLog(IName,"setDeviceForecast: " & e.Message)
	End Try
End Sub

Sub setDeviceHumidity(ByVal node1 as String)
	Dim fs as Object
	Dim devHumidity as String
	hs.SaveINISetting("WeatherInfo","Humidity",node1,sINI)
	devHumidity = hs.GetINISetting ("Settings","devHumidity","",sINI)
	if len(trim(devHumidity)) > 0 Then
		fs = hs.CreateStringClass
			fs.Add(sTableStartCode)
			if UseIcons = True Then
				fs.Add("<img src='\images\weathericons\other\humidity_icon.gif' align='middle'>")
			End if
			fs.Add(sTableMidCode)
			if useHeadings = True Then
				fs.Add(useHeadingStyle)
				fs.Add(hs.GetINISetting("Language","humidity","Relative vochtigheid",sINI))
				fs.Add(":</span><br/>")
			End if
			fs.Add(node1)
			fs.Add("%")
			fs.Add(sTableEndCode)
			hs.SetDeviceString(devHumidity, fs.Value,True)
			if IsNumeric(node1) Then
				hs.SetDeviceValue(devHumidity, CInt(node1))
			Else
				hs.SetDeviceValue(devHumidity,0)
			End if
			fs.Reset
		fs = Nothing
	End if
End Sub

Sub setDeviceLike(ByVal node1 as String)
	Dim fs as Object
	Dim devFeelsLike as String
	if isNumeric(node1) Then
		node1=cInt(node1)
	End if
	hs.SaveINISetting ("WeatherInfo","FeelsLike",node1,sINI)
	devFeelsLike = (hs.GetINISetting ("Settings","devFeelsLike","",sINI))
	if len(trim(devFeelsLike)) > 0 Then
		fs = hs.CreateStringClass
			fs.Add(sTableStartCode)
			if UseIcons = True AND node1 <> "N/A" Then
				fs.Add("<img src='\images\weathericons\thermos\")
				fs.Add(node1)
				fs.Add(".gif' width='36' height='77' align='middle'>")
			End if
			fs.Add(sTableMidCode)
			if useHeadings = True Then
				fs.Add(useHeadingStyle)
				fs.Add(hs.GetINISetting("Language","currentFeelsLike","Huidige temperatuur voelt aan als",sINI))
				fs.Add(":</span><br/>")
			End if
			fs.Add(node1)
			if node1 <> "N/A" Then
				fs.Add("&deg; ")
				fs.Add(hs.GetINISetting("InfoUnit","Temperature","",sINI))
			End if
			fs.Add(sTableEndCode)
			hs.SetDeviceString(devFeelsLike,fs.Value,True)
			if isNumeric(node1) Then
				hs.SetDeviceValue(devFeelsLike,node1)
			End if
		fs = Nothing
	End if
End Sub

Sub setDeviceTemp(ByVal node1 as String, ByVal node2 as String)
	Dim fs as Object
	Dim devTemp as String
	node1 = cInt(node1)
	if isNumeric(node2) Then
		node2 = cInt(node2)
	End if
	hs.SaveINISetting ("WeatherInfo","CurrentTemp",node1,sINI)
	devTemp = hs.GetINISetting ("Settings","devTemp","",sINI)
	if len(trim(devTemp)) > 0 Then
		fs = hs.CreateStringClass
			fs.Add (sTableStartCode)
			if UseIcons = "True" Then
				fs.Add("<img src='\images\weathericons\thermos\")
				fs.Add(node1)
				fs.Add(".gif' width='36' height='77' align='middle'>")
			End if
			fs.Add(sTableMidCode)
			if useHeadings = True Then
				fs.Add(useHeadingStyle)
				fs.Add(hs.GetINISetting("Language","currentTemperature","Huidige temperatuur",sINI))
				fs.Add(":")
				fs.Add("</span><br/>")
			End if
			fs.Add(hs.GetINISetting ("Location","CityState","",sINI))
			fs.Add("<br>")
			fs.Add(node1)
			fs.Add("&deg; ")
			fs.Add(hs.GetINISetting("InfoUnit","Temperature","",sINI))
			if isNumeric(node2) Then
				fs.Add(" <br> Wat aanvoelt als ")
				fs.Add(node2)
				fs.Add("&deg; ")
				fs.Add(hs.GetINISetting("InfoUnit","Temperature","",sINI))
			End if
			fs.Add(sTableEndCode)
			hs.SetDeviceString(devTemp,fs.Value,True)
			hs.SetDeviceValue(devTemp,node1)
			fs.Reset
		fs = Nothing
	End if	
End sub

Sub setDeviceUpdated(ByVal node1 as String, ByVal node2 as String)
	Dim fs as Object
	Dim devUpdated, intValue as String
	' Last Updated
	devUpdated = hs.GetINISetting ("Settings","devUpdated","",sINI)
	if len(trim(devUpdated)) > 0 Then
		intValue = node2
		fs = hs.CreateStringClass
			fs.Add(sTableStartCode)
			if UseIcons = True Then
				fs.Add("<img src='/clock.gif' align='middle'>")
			End if
			fs.Add(sTableMidCode)
			if useHeadings = True Then
				fs.Add(useHeadingStyle)
				fs.Add(hs.GetINISetting("Language","updated","Updated",sINI))
				fs.Add(":</span><br/>")
			End if
			fs.Add (hs.GetINISetting("Location","CityState","",sINI))
			fs.Add(" (")
			fs.Add (hs.GetINISetting ("Settings","postcode","",sINI))
			fs.Add(") <br>")
			fs.Add("Laatst ")
			fs.Add(hs.GetINISetting("Language","updated","Ververst",sINI))
			fs.Add(" ")
			fs.Add(intValue)
			fs.Add("<br>HomeSeer Laatst ")
			fs.Add(hs.GetINISetting("Language","updated","Ververst",sINI))
			fs.Add(": ")
			fs.Add(FormatDateTime(Now,vbLongDate))
			fs.Add(" om ")
			fs.Add(FormatDateTime(Now,vbLongTime))
			fs.Add("<br>")
			fs.Add(sTableEndCode)
			fs.Add(hs.RunEx("AZ_weatherXML_web.vb","providerLinks","",true))
			hs.SetDeviceString(devUpdated,fs.Value,True)
			fs.Reset
		fs = Nothing
	End if
End Sub

Sub setDeviceVisibility(ByVal node1 as String)
	Dim fs as Object
	Dim devVisibility as String
	hs.SaveINISetting("WeatherInfo","Visibility",node1,sINI)
	devVisibility = hs.GetINISetting ("Settings","devVisibility","",sINI)
	if len(trim(devVisibility)) > 0 Then
		fs = hs.CreateStringClass
			fs.Add(sTableStartCode)
			if UseIcons = True Then
				fs.Add("<img src='\images\weathericons\other\Visibility.gif' align='middle'>")
			End if
			fs.Add(sTableMidCode)
			if useHeadings = True Then
				fs.Add(useHeadingStyle)
				fs.Add(hs.GetINISetting("Language","visibility","Zicht",sINI))
				fs.Add(":</span><br/>")
			End if
			fs.Add(node1)
			fs.Add(" ")
			fs.Add(hs.GetINISetting("InfoUnit","Distance","",sINI))
			fs.Add(sTableEndCode)
			hs.SetDeviceString(devVisibility,fs.Value,True)
			if IsNumeric(node1)  Then
				hs.SetDeviceValue(devVisibility,CInt(node1))
			Else
				hs.SetDeviceValue(devVisibility,0)
			End if
		fs = Nothing
	End if
End Sub

Sub setDeviceWindDir(ByVal node1 as String)
	Dim fs as Object
	Dim devWindDir as String
	Try
		hs.SaveINISetting("WeatherInfo","WindDirection",node1,sINI)
		devWindDir = hs.GetINISetting ("Settings","devWindDir","",sINI)
		if len(trim(devWindDir)) > 0 Then
			fs = hs.CreateStringClass
				fs.Add(sTableStartCode)
				if UseIcons = True Then
					fs.Add("<img src='\images\weathericons\wind\")
					fs.Add(hs.RunEx("AZ_weatherXML_web.vb","windDirImage",node1,True))
					fs.Add(".gif' align='middle'>")
				End if
				fs.Add(sTableMidCode)
				if useHeadings = True Then
					fs.Add(useHeadingStyle)
					fs.Add(hs.GetINISetting("Language","windDirection","Windrichting",sINI))
					fs.Add(":</span><br/>")
				End if
				fs.Add(directionText(node1))
				fs.Add(sTableEndCode)
				hs.SetDeviceString(devWindDir,fs.Value,True)
			fs = Nothing
		End if
	Catch e as Exception
		hs.WriteLog(IName,"setDeviceWindDir: " & e.Message)
	End Try
End Sub

Sub setDeviceWindDeg(ByVal node1 as String)
	Dim fs as Object
	Dim devWindDegrees as String
	hs.SaveINISetting("WeatherInfo","WindDegrees",node1,sINI)
	devWindDegrees = hs.GetINISetting ("Settings","devWindDegrees","",sINI)
	if len(trim(devWindDegrees)) > 0 Then
		fs = hs.CreateStringClass
			fs.Add(sTableStartCode)
			fs.Add(sTableMidCode)
			if useHeadings = True Then
				fs.Add(useHeadingStyle)
				fs.Add(hs.GetINISetting("Language","windDegrees","Windrichting in graden",sINI))
				fs.Add(":</span><br/>")
			End if
			fs.Add(node1)
			fs.Add(sTableEndCode)
			hs.SetDeviceString(devWindDegrees,fs.Value,True)
		fs = Nothing
	End if
End Sub

Sub setDeviceWindGust(ByVal node1 as String)
	Dim fs as Object
	Dim devWindGust as String
	hs.SaveINISetting("WeatherInfo","Windgust",node1,sINI)
	devWindGust = hs.GetINISetting ("Settings","devWindGust","",sINI)
	if len(trim(devWindGust)) > 0 Then
		fs = hs.CreateStringClass
			fs.Add(sTableStartCode)
			fs.Add(sTableMidCode)
			if useHeadings = True Then
				fs.Add(useHeadingStyle)
				fs.Add(hs.GetINISetting("Language","windGust","Windstoten",sINI))
				fs.Add(":</span><br/>")
			End if
			if len(trim(node1)) = 0 OR node1 = "N/A" Then
				fs.Add("N/A")
			Else
				fs.Add(node1)
				fs.Add(" ")
				fs.Add(hs.GetINISetting("InfoUnit","Speed","mph",sINI))
			End if
			fs.Add(sTableEndCode)
			hs.SetDeviceString(devWindGust,fs.Value,True)
			fs.Reset
		fs = Nothing
	End if
End Sub

Sub setDeviceWindSpeed(ByVal node1 as String)
	Dim fs as Object
	Dim nSpeed, devWind, sWindDir, sWindDeg, sWindGust, sUnit as String
	hs.SaveINISetting("WeatherInfo","WindSpeed",node1,sINI)
	sWindDir = hs.GetINISetting("WeatherInfo","WindDirection","",sINI)
	sWindDeg = hs.GetINISetting("WeatherInfo","WindDegrees","",sINI)
	sWindGust = hs.GetINISetting("WeatherInfo","Windgust","",sINI)
	devWind = hs.GetINISetting ("Settings","devWind","",sINI)
	if len(trim(devWind)) > 0 Then
		fs = hs.CreateStringClass
			sUnit = hs.GetINISetting("InfoUnit","Speed","",sINI)
			fs.Add(sTableStartCode)
			if UseIcons = True Then
				fs.Add("<img src='\images\weathericons\wind\")
				fs.Add(hs.RunEx("AZ_weatherXML_web.vb","windDirImage",sWindDir,True))
				fs.Add(".gif' align='middle'>")
			End if
			fs.Add(sTableMidCode)
			if useHeadings = True Then
				fs.Add(useHeadingStyle)
				fs.Add(hs.GetINISetting("Language","windSpeed","Windsnelheid",sINI))
				fs.Add(":</span><br/>")
			End if
			fs.Add("De wind ")
			if lCase(sWindDir) = "calm" OR node1 = "0" Then
				fs.Add("is rustig")
			Else
				if isNumeric(node1) Then
					if node1 > 0 Then
						fs.Add("komt uit ")
						fs.Add(directionText(sWindDir))
						fs.Add(" en is ")
						fs.Add(node1)
						fs.Add(" ")
						fs.Add(sUnit)
					End if
				End if
			End if
			fs.Add(".  ")
			if len(trim(sWindGust)) > 0 AND sWindGust <> "N/A" Then
				if sWindGust > 0 Then
					fs.Add("Windstoten van ")
					fs.Add(sWindGust)
					fs.Add(" ")
					fs.Add(sUnit)
					fs.Add(".  ")
				End if
			End if
			fs.Add(sTableEndCode)
			hs.SetDeviceString(devWind,fs.Value,True)
			if IsNumeric(node1) Then
				hs.SetDeviceValue(devWind,CInt(node1))
			Else
				hs.SetDeviceValue(devWind,0)
			End if
			fs.Reset
		fs = Nothing
	End if
End Sub

Sub weatherNOAAData(Optional ByVal sParam as String = "")
	Dim bChk as Boolean = False
	Dim bWd as Boolean = False
	Dim bRh as Boolean = False
	Dim dRun as Date = Now()
	Dim x, x2, y as Integer
	Dim curTemp, cBar, wcTemp, wcWind, wcHum, wkWind as Single
	Dim fs, xmlfile, oNodeList, oNode, oNList, oNListNode, xNode, xNode2 as Object
	Dim strXMLFile, sForecastFile, strPartnerID, innerHeading, sLastUp, sWindDir, feelLike as String
	Dim dTime, dChk, sDay, sValue, sNightDay, sToggle, sName, sFC, sImage, unitTemp as String
	Try
	' download the XML file
	strXMLFile = downloadNOAAXML()
	unitTemp = hs.GetINISetting("InfoUnit","Temperature","F",sINI)
	fs = hs.CreateStringClass
			' Make sure the file downloaded
			if XMLFileExists(strXMLFile) = False Then
				Exit Sub
			End if
			' Start the import from the XML file
			xmlfile = CreateObject("Microsoft.XMLDOM")
				xmlfile.async=false
				xmlfile.load(strXMLFile)
					hs.SaveINISetting("Debug","ErrorCodeNC",xmlfile.parseError.errorcode,sINI)
					if xmlfile.parseError.errorcode <> 0 Then
						fs.Add("There was an error with the XML file.  Error Reason: ")
						fs.Add(xmlfile.parseError.reason)
						hs.WriteLog(IName,fs.Value)
						fs.Reset
						dRun = dRun.addMinutes(-30)
						hs.SaveINISetting("Settings","lastranNC",dRun,sINI)
						hs.SaveINISetting("Debug","ErrorReasonNC",trim(xmlfile.parseError.reason),sINI)
						hs.SaveINISetting("Debug","ErrorTimeNC",trim(Now()),sINI)
					End if
					if xmlfile.parseError.errorcode = 0 Then
						getINIValues()
						oNodeList = xmlfile.getElementsByTagName("current_observation")
							oNode = oNodeList.nextNode
								if len(trim(hs.GetINISetting("Settings","updlocation","",sINI))) > 0 Then
									hs.SaveINISetting("Location","CityState",trim(hs.GetINISetting("Settings","updlocation","",sINI)),sINI)
								Else
									hs.SaveINISetting("Location","CityState",oNode.selectSingleNode("location").Text,sINI)
								End if
								Try
									sLastUp = oNode.selectSingleNode("observation_time").Text
									sLastUp = replace(sLastUp,"Laatst ververst op ","")
									hs.SaveINISetting ("Location","TimeChecked",sLastUp,sINI)
									' Last Updated
									setDeviceUpdated(sLastUp,sLastUp)
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing the observation time: " & ex.Message)
								End Try
								Try
									' Current Temp
									if unitTemp = "F" Then
										curTemp = oNode.selectSingleNode("temp_f").Text
									Else
										curTemp = oNode.selectSingleNode("temp_c").Text
									End if
									' Check the temp for daily hi low values
									if debugMode = True Then 
										hs.WriteLog(IName,"Checking Daily Hi/Low: " & curTemp)
									End if
									setDailyHiLow(curTemp)
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing the current temperature: " & ex.Message)
								End Try
								Try
									' Humidity
									xNode = oNode.selectSingleNode("relative_humidity")
									if Not xNode Is Nothing Then
										wcHum = oNode.selectSingleNode("relative_humidity").Text
										if debugMode = True Then 
											hs.WriteLog(IName,"Checking Humidity: " & wcHum)
										End if
										setDeviceHumidity(wcHum)
										bRh = True
									Else
										setDeviceHumidity("")
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing the humidity: " & ex.Message)
								End Try
								Try
									' Wind Gust
									xNode = oNode.selectSingleNode("wind_gust_mph")
									if Not xNode Is Nothing Then
										sValue = oNode.selectSingleNode("wind_gust_mph").text
										if hs.GetINISetting("InfoUnit","speedUnit","mph",sINI) = "kmph" Then
											if isNumeric(oNode.selectSingleNode("wind_gust_mph").text) Then
												sValue = convertMPH(sValue)
											End if
										End if
										setDeviceWindGust(sValue)
									Else
										setDeviceWindGust("")
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing the wind gust: " & ex.Message)
								End Try
								Try
									' Wind Degrees
									xNode = oNode.selectSingleNode("wind_degrees")
									if Not xNode Is Nothing Then
										setDeviceWindDeg(oNode.selectSingleNode("wind_degrees").text)
									Else
										setDeviceWindDeg("")
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing the wind degrees: " & ex.Message)
								End Try
								Try
									' Wind Direction
									xNode = oNode.selectSingleNode("wind_dir")
									if Not xNode Is Nothing Then
										sWindDir = hs.RunEx("AZ_weatherXML_web.vb","windDirImage",oNode.selectSingleNode("wind_dir").text,True) 
										if debugMode = True Then 
											hs.WriteLog(IName,"Checking Wind Dir: " & sWindDir)
										End if
										setDeviceWindDir(sWindDir)
									Else
										setDeviceWindDir("")
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing the wind direction: " & ex.Message)
								End Try
								Try
									' Wind Speed
									xNode = oNode.selectSingleNode("wind_mph")
									if Not xNode Is Nothing Then
										wcWind = oNode.selectSingleNode("wind_mph").text
										if debugMode = True Then 
											hs.WriteLog(IName,"Checking Wind Speed: " & wcWInd)
										End if
										if hs.GetINISetting("InfoUnit","speedUnit","mph",sINI) = "kmph" Then
											wKWind = convertMPH(wcWind)
										Else 
											wkWind = wcWind
										End if
										setDeviceWindSpeed(wkWind)
										bWd = True
									Else
										if debugMode = True Then 
											hs.WriteLog(IName,"setting Wind Speed to nothing.")
										End if
										setDeviceWindSpeed("")
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing the wind speed: " & ex.Message)
								End Try
								Try
									' Feel like
									feelLike = "N/A"
									if debugMode = True Then 
										hs.WriteLog(IName,"Check Feels Like: Temp: " & curTemp & "  Wind: " & wcWind & " Humidity: " & wcHum)
									End if
									if uCase(unitTemp) = "F" Then
										xNode = oNode.selectSingleNode("windchill_f")
										xNode2 = oNode.selectSingleNode("heat_index_f")
									Else
										xNode = oNode.selectSingleNode("windchill_c")
										xNode2 = oNode.selectSingleNode("heat_index_c")
									End if
									if xNode Is Nothing AND xNode2 Is Nothing Then
										bChk = True
									Else
										bChk = true
										if curTemp > 80 Then
											if Not xNode2 Is Nothing THen
												if uCase(unitTemp) = "F" Then
													feelLike = oNode.selectSingleNode("heat_index_f").text
													if isNumeric(feelLike) Then
														bChk = false
													End if
												Else
													feelLike = oNode.selectSingleNode("heat_index_c").text
													if isNumeric(feelLike) Then
														bChk = false
													End if
												End if
											End if
										Else
											if Not xNode Is Nothing Then
												if uCase(unitTemp) = "F" Then
													feelLike = oNode.selectSingleNode("windchill_f").text
													if isNumeric(feelLike) Then
														bChk = false
													End if
												Else
													feelLike = oNode.selectSingleNode("windchill_c").text
													if isNumeric(feelLike) Then
														bChk = false
													End if
												End if
											End if
										End if
									End if
									if bChk = true Then
										if uCase(unitTemp) = "F" Then
											wcTemp = curTemp 
										Else
											wcTemp = curTemp*(9/5)+32
										End if
										if isNumeric(wcTemp) Then
											feelLike = getFeelsLike(wcTemp,wcWind,wcHum)
											if isNumeric(feelLike) Then
												if uCase(unitTemp) <> "F" Then
													feelLike = (feelLike-32)/9*5
												End if
											End if
										End if
									End if
									' Feels Like
									if debugMode = True Then 
										hs.WriteLog(IName,"Setting Feels Like: " & feelLike)
									End if
									setDeviceLike(feelLike)
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing feels like: " & ex.Message)
								End Try
								Try
									' Current Temperature
									if debugMode = True Then 
										hs.WriteLog(IName,"setDeviceTemp: " & curTemp)
									End if
									setDeviceTemp(curTemp,feelLike)
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing current temp: " & ex.Message)
								End Try
								Try
									' Condition & Condition Icon
									fs.Add(oNode.selectSingleNode("icon_url_base").Text)
									fs.Add(oNode.selectSingleNode("icon_url_name").Text)
									sImage = fs.Value
									fs.Reset
									setDeviceCondition(oNode.selectSingleNode("weather").Text,sImage)
									' Condition Image
									setDeviceCondImage()
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing the condition icon: " & ex.Message)
								End Try
								Try
									' Dewpoint
									if unitTemp = "F" Then
										setDeviceDoTheDew(oNode.selectSingleNode("dewpoint_f").Text)
									Else
										setDeviceDoTheDew(oNode.selectSingleNode("dewpoint_c").Text)
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing dewpoint: " & ex.Message)
								End Try
								Try
									' Barometer
									if hs.GetINISetting ("InfoUnit","pressureUnit","i",sINI) = "i" Then
										xNode = oNode.selectSingleNode("pressure_in")
									Else
										xNode = oNode.selectSingleNode("pressure_mb")
									End if
									dTime = oNode.selectSingleNode("observation_time_rfc822").text
									dChk = hs.GetINISetting("WeatherInfo","BarometerTime","",sINI)
									if Not xNode Is Nothing Then
										if hs.GetINISetting ("InfoUnit","pressureUnit","i",sINI) = "i" Then
											cBar = oNode.selectSingleNode("pressure_in").text
										Else
											cBar = oNode.selectSingleNode("pressure_mb").text
										End if
										if trim(dTime) <> trim(dChk) Then
											setDeviceBarometer(cBar,dTime)
										Else
											setDeviceBarometer(cBar)
										End if
									Else
										setDeviceBarometer("","")
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing barometer: " & ex.Message)
								End Try
								Try
									' Visibility
									xNode = oNode.selectSingleNode("visibility_mi")
									if Not xNode Is Nothing Then
										sValue = oNode.selectSingleNode("visibility_mi").Text
										if hs.GetINISetting("InfoUnit","distanceUnit","m",sINI) = "km" Then
											sValue = convertMPH(sValue)
										End if
										setDeviceVisibility(sValue)
									Else
										setDeviceVisibility("")
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error accessing visibility: " & ex.Message)
								End Try
							oNode = Nothing
						oNodeList = Nothing
					End if
			xmlfile = Nothing
		fs = Nothing
		if debugMode = True Then
			hs.WriteLog(IName,"Finished importing weather current information from NOAA.")
		End if
	Catch e as Exception
		hs.Writelog(IName,"weatherNOAAData " & e.Message)
	End Try
End Sub

Sub weatherNOAAForecast(Optional ByVal sParam as String = "")
	Dim dRun as date
	Dim x, x2, y as Integer
	Dim fs, xmlfile, oNodeList, oNode, xNode as Object
	Dim sForecastFile, sDay, sValue, sIconName, sNightDay, sToggle, sName, sFC, unitTemp as String
	Try
		sForecastFile = downloadNOAAForecast()
		unitTemp = hs.GetINISetting("InfoUnit","Temperature","F",sINI)
		fs = hs.CreateStringClass
			' Make sure the file downloaded
			if XMLFileExists(sForecastFile) = False Then
				Exit Sub
			End if
			' Start the import from the XML file
			xmlfile = CreateObject("Microsoft.XMLDOM")
				xmlfile.async=false
				xmlfile.load(sForecastFile)
					hs.SaveINISetting ("Debug","ErrorCodeNF",xmlfile.parseError.errorcode,sINI)
					if xmlfile.parseError.errorcode <> 0 Then
						fs.Add("There was an error with the forecast XML file.  Error Reason: ")
						fs.Add(xmlfile.parseError.reason)
						hs.WriteLog(IName,fs.Value)
						fs.Reset
						hs.SaveINISetting("Settings","lastranNF",dRun,sINI)
						hs.SaveINISetting ("Debug","ErrorReasonNF",xmlfile.parseError.reason,sINI)
						hs.SaveINISetting("Debug","ErrorTimeNF",trim(Now()),sINI)
					End if
					if xmlfile.parseError.errorcode = 0 Then
						' Clear the old data
						hs.Runex("AZ_weatherXML_wu.vb","clearINIData",10,True)
						hs.Runex("AZ_weatherXML_wu.vb","clearOldINIData",20,True)
						' Enter the new data
						if debugMode = True Then
							fs.Add("Begining weatherXML import of ")
							fs.Add(sForecastFile)
							hs.WriteLog(IName,fs.Value)
							fs.Reset
						End if
						oNodeList = xmlfile.getElementsByTagName("./data")
							for x = 0 to oNodeList.Length-1
								oNode = oNodeList.nextNode
								xNode = oNode.selectNodes("time-layout")
								if Not (xNode Is Nothing) Then
									For x2 = 0 to oNode.selectNodes("time-layout").length - 1
										sValue = oNode.selectNodes("time-layout").item(x2).selectSingleNode("layout-key").text
										if sValue = "k-p12h-n15-1" OR sValue = "k-p12h-n13-1" OR sValue = "k-p12h-n14-1" Then
											if sValue = "k-p12h-n15-1" OR sValue = "k-p12h-n13-1" Then
												sNightDay = "today"
												if debugMode = True Then
													hs.WriteLog(IName,"Forecast starting with today")
												End if
											Elseif sValue = "k-p12h-n14-1" Then
												sNightDay = "tonight"
												if debugMode = True Then
													hs.WriteLog(IName,"Forecast starting with tonight")
												End if
											End if
											xNode = oNode.selectNodes("time-layout").item(x2).selectNodes("start-valid-time")
											if Not (xNode Is Nothing) Then
												x = 1
												For y = 0 to oNode.selectNodes("time-layout").item(x2).selectNodes("start-valid-time").length-1
													fs.Add("DayDate")
													fs.Add(x)
													sDay = oNode.selectNodes("time-layout").item(x2).selectNodes("start-valid-time").item(y).text
													hs.SaveINISetting("Forecast",fs.Value,FormatDateTime(sDay,2),sINI)
													fs.Reset
													fs.Add("DayName")
													fs.Add(x)
													hs.SaveINISetting("Forecast",fs.Value,cDate(sDay).toString("dddd"),sINI)
													fs.Reset
													sName = lCase(oNode.selectNodes("time-layout").item(x2).selectNodes("start-valid-time").item(y).getAttribute("period-name"))
													if sName.IndexOf("night") > 0 Then
														x = x + 1
													End if
												Next										
											End if
										End if
									Next
								End if
								xNode = oNode.selectSingleNode("parameters").selectNodes("temperature")
								if Not (xNode Is Nothing) Then
									For x2 = 0 to oNode.selectSingleNode("parameters").selectNodes("temperature").length - 1
										xNode = oNode.selectSingleNode("parameters").selectNodes("temperature").item(x2).selectNodes("value")
										if Not (xNode Is Nothing) Then
											For y = 0 to oNode.selectSingleNode("parameters").selectNodes("temperature").item(x2).selectNodes("value").length-1
												sValue = oNode.selectSingleNode("parameters").selectNodes("temperature").item(x2).selectNodes("value").item(y).text
												if oNode.selectSingleNode("parameters").selectNodes("temperature").item(x2).getAttribute("type") = "maximum" Then
													fs.Add("DayHi")
													if sNightDay = "tonight" Then
														fs.Add(y+2)
													Else
														fs.Add(y+1)
													End if
													if isNumeric(sValue) Then
														hs.SaveINISetting("Forecast",fs.Value,sValue,sINI)
													Else
														hs.SaveINISetting("Forecast",fs.Value,"",sINI)
													End if
													fs.Reset
												Elseif oNode.selectSingleNode("parameters").selectNodes("temperature").item(x2).getAttribute("type") = "minimum" Then
													fs.Add("DayLow")
													fs.Add(y+1)
													if isNumeric(sValue) Then
														hs.SaveINISetting("Forecast",fs.Value,sValue,sINI)
													Else
														hs.SaveINISetting("Forecast",fs.Value,"",sINI)
													End if
													fs.Reset
												End if
											Next
										End if
									Next
								End if
								xNode = oNode.selectSingleNode("parameters").selectSingleNode("probability-of-precipitation").selectNodes("value")
								if Not (xNode Is Nothing) Then
									sToggle = sNightDay
									y = 1
									For x2 = 0 to oNode.selectSingleNode("parameters").selectSingleNode("probability-of-precipitation").selectNodes("value").length - 1
										sValue = oNode.selectSingleNode("parameters").selectSingleNode("probability-of-precipitation").selectNodes("value").item(x2).text									
										if sToggle = "today" Then
											fs.Add("DayPrecipitation")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											sToggle="tonight"
										Elseif sToggle = "tonight" Then
											fs.Add("NightPrecipitation")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											sToggle="day"
											y = y + 1
										Elseif sToggle = "day" Then
											fs.Add("DayPrecipitation")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											sToggle="night"
										Else
											fs.Add("NightPrecipitation")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											sToggle="day"
											y = y + 1
										End if
									Next
								End if
								xNode = oNode.selectSingleNode("parameters").selectSingleNode("weather").selectNodes("weather-conditions")
								if Not (xNode Is Nothing) Then
									sToggle = sNightDay
									y = 1
									For x2 = 0 to oNode.selectSingleNode("parameters").selectSingleNode("weather").selectNodes("weather-conditions").length - 1
										sValue = oNode.selectSingleNode("parameters").selectSingleNode("weather").selectNodes("weather-conditions").item(x2).getAttribute("weather-summary")
										if sToggle = "today" Then
											fs.Add("DayCondition")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											sToggle="tonight"
										Elseif sToggle = "tonight" Then
											fs.Add("NightCondition")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											sToggle="day"
											y = y + 1
										Elseif sToggle = "day" Then
											fs.Add("DayCondition")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											sToggle="night"
										Else
											fs.Add("NightCondition")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											sToggle="day"
											y = y + 1
										End if
									Next
								End if
								xNode = oNode.selectSingleNode("parameters").selectSingleNode("conditions-icon").selectNodes("icon-link")
								if Not (xNode Is Nothing) Then
									sToggle = sNightDay
									y = 1
									For x2 = 0 to oNode.selectSingleNode("parameters").selectSingleNode("conditions-icon").selectNodes("icon-link").length - 1
										sValue = oNode.selectSingleNode("parameters").selectSingleNode("conditions-icon").selectNodes("icon-link").item(x2).text
										if sToggle = "today" Then
											fs.Add("DayIcon")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											fs.Add("DayIconName")
											fs.Add(y)
											sIconName = hs.RunEx("AZ_weatherXML_wu.vb","saveIcon",sValue,True)
											hs.SaveINISetting("forecast",fs.Value,sIconName,sINI)
											fs.Reset
											sToggle="tonight"
										Elseif sToggle = "tonight" Then
											fs.Add("NightIcon")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											fs.Add("NightIconName")
											fs.Add(y)
											sIconName = hs.RunEx("AZ_weatherXML_wu.vb","saveIcon",sValue,True)
											hs.SaveINISetting("forecast",fs.Value,sIconName,sINI)
											fs.Reset
											sToggle="day"
											y = y + 1
										Elseif sToggle = "day" Then
											fs.Add("DayIcon")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											fs.Add("DayIconName")
											fs.Add(y)
											sIconName = hs.RunEx("AZ_weatherXML_wu.vb","saveIcon",sValue,True)
											hs.SaveINISetting("forecast",fs.Value,sIconName,sINI)
											fs.Reset
											sToggle="night"
										Else
											fs.Add("NightIcon")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											fs.Add("NightIconName")
											fs.Add(y)
											sIconName = hs.RunEx("AZ_weatherXML_wu.vb","saveIcon",sValue,True)
											hs.SaveINISetting("forecast",fs.Value,sIconName,sINI)
											fs.Reset
											sToggle="day"
											y = y + 1
										End if
									Next
								End if
								xNode = oNode.selectSingleNode("parameters").selectSingleNode("wordedForecast").selectNodes("text")
								if Not (xNode Is Nothing) Then
									sToggle = sNightDay
									y = 1
									For x2 = 0 to oNode.selectSingleNode("parameters").selectSingleNode("wordedForecast").selectNodes("text").length - 1
										sValue = oNode.selectSingleNode("parameters").selectSingleNode("wordedForecast").selectNodes("text").item(x2).text
										if sToggle = "today" Then
											fs.Add("DayForecast")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											fs.Add("Today: ")
											fs.Add(sValue)
											sFC = fs.Value
											fs.Reset
											fs.Add("ExtForecast")
											fs.Add(x2+1)
											hs.SaveINISetting("WeatherCom_ExtForecast",fs.Value,trim(sFC),sINI)
											fs.Reset
											sToggle="tonight"
										Elseif sToggle = "tonight" Then
											fs.Add("NightForecast")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,sValue,sINI)
											fs.Reset
											fs.Add("Tonight: ")
											fs.Add(sValue)
											sFC = fs.Value
											fs.Reset
											fs.Add("ExtForecast")
											fs.Add(x2+1)
											hs.SaveINISetting("WeatherCom_ExtForecast",fs.Value,trim(sFC),sINI)
											fs.Reset
											sToggle="day"
											y = y + 1
										Elseif sToggle = "day" Then
											fs.Add("DayForecast")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,trim(sValue),sINI)
											fs.Reset
											fs.Add("DayName")
											fs.Add(y)
											sFC = hs.GetINISetting("forecast",fs.Value,"",sINI)
											fs.Reset
											fs.Add(sFC)
											fs.Add(": ")
											fs.Add(sValue)
											sFC = fs.Value
											fs.Reset
											fs.Add("ExtForecast")
											fs.Add(x2+1)
											hs.SaveINISetting("WeatherCom_ExtForecast",fs.Value,trim(sFC),sINI)
											fs.Reset
											sToggle="night"
										Else
											fs.Add("NightForecast")
											fs.Add(y)
											hs.SaveINISetting("forecast",fs.Value,trim(sValue),sINI)
											fs.Reset
											fs.Add("DayName")
											fs.Add(y)
											sFC = hs.GetINISetting("forecast",fs.Value,"",sINI)
											fs.Reset
											fs.Add(sFC)
											fs.Add(" Night: ")
											fs.Add(sValue)
											sFC = fs.Value
											fs.Reset											
											fs.Add("ExtForecast")
											fs.Add(x2+1)
											hs.SaveINISetting("WeatherCom_ExtForecast",fs.Value,trim(sFC),sINI)
											fs.Reset
											sToggle="day"
											y = y + 1
										End if
									Next
								End if
							Next
						oNodeList = Nothing		
					End if
					setDeviceForecast()
			xmlfile = Nothing
		fs = Nothing
		if debugMode = True Then
			hs.WriteLog(IName,"Finished importing weather forecast information from NOAA.")
		End if
	Catch e as Exception
		hs.Writelog(IName,"weatherNOAAForecast " & e.Message)
	End Try
End Sub

Sub weatherWUData(Optional ByVal sParam as String = "")
	Try
		Dim aFiles as Array
		Dim x as Integer
		Dim sFile, sTemp, sWhereFrom as String
		aFiles = Split(hs.GetINISetting("Settings","WUFiles","",sINI),",")
		sWhereFrom = hs.GetINISetting("settings","xmlSource","",sINI)
		For x = 0 to UBound(aFiles)
			sFile = downloadWUXML(aFiles(x))
			if len(trim(sFile)) > 0 Then
				Select Case lCase(aFiles(x))
					Case "alerts"
						if debugMode = True Then
							hs.WriteLog(IName,"Running import Weather Underground alerts")
						End if
						if XMLFileExists(sFile) = True Then
							sTemp = ""
						End if
					Case "almanac"
						if debugMode = True Then
							hs.WriteLog(IName,"Running import Weather Underground almanac")
						End if
						if XMLFileExists(sFile) = True Then
							hs.RunEx("AZ_weatherXML_wu.vb","importAlmanac",sFile,true)
						End if
					Case "astronomy"
						if debugMode = True Then
							hs.WriteLog(IName,"Running import Weather Underground astronomy")
						End if
						if XMLFileExists(sFile) = True Then
							hs.RunEx("AZ_weatherXML_wu.vb","importAstronomy",sFile,true)
						End if
					Case "conditions"
						if debugMode = True Then
							hs.WriteLog(IName,"Running import Weather Underground conditions")
						End if
						if XMLFileExists(sFile) = True Then
							importCondition(sFile)
						End if
					Case "forecast"
						if sWhereFrom = "wu" Then
							if debugMode = True Then
								hs.WriteLog(IName,"Running import Weather Underground forecast")
							End if
							if XMLFileExists(sFile) = True Then
								hs.RunEx("AZ_weatherXML_wu.vb","importForecast",sFile,true)
							End if
						End if
					Case "history"
						if debugMode = True Then
							hs.WriteLog(IName,"Running import Weather Underground history")
						End if
						if XMLFileExists(sFile) = True Then
							hs.RunEx("AZ_weatherXML_wu.vb","importHistory",sFile,true)
						End if
					Case "hourly7day"
						if debugMode = True Then
							hs.WriteLog(IName,"Running import Weather Underground almanac")
						End if
						if XMLFileExists(sFile) = True Then
							hs.RunEx("AZ_weatherXML_wu.vb","importForecastHourly",sFile,true)
						End if
				End Select
			End if
		Next
		if debugMode = True Then
			hs.WriteLog(IName,"Finished importing from weather underground.")
		End if
	Catch e as Exception
		hs.Writelog(IName,"weatherWUData " & e.Message)
	End Try
End Sub

Sub weatherWWOData(Optional ByVal sParam as String = "")
	Dim bChk as Boolean = False
	Dim bWd as Boolean = False
	Dim bRh as Boolean = False
	Dim dRun as Date = Now()
	Dim dTemp as Date = Now()
	Dim x, x2, y as Integer
	Dim fs, xmlfile, oNodeList, oNode, oNList, oNListNode, xNode, xNode2 as Object
	Dim curTemp, cBar, wcTemp, wcWind, wcHum, wkWind, nVisible as Single
	Dim strXMLFile, unitTemp, innerHeading, sLastUp, sWindDir, feelLike as String
	Dim dTime, dChk, sDay, sValue, sNightDay, sToggle, sName, sFC, sImage as String
	Dim sCond, sHigh, sLow, sWndSpd, sWndDir, sDayText, sDayName, sVisible, sIconName as String
	Try
		' download the XML file
		strXMLFile = downloadWWOXML()
		unitTemp = hs.GetINISetting("InfoUnit","Temperature","F",sINI)
		fs = hs.CreateStringClass
			' Make sure the file downloaded
			if XMLFileExists(strXMLFile) = False Then
				Exit Sub
			End if
			' Start the import from the XML file
			xmlfile = CreateObject("Microsoft.XMLDOM")
				xmlfile.async=false
				xmlfile.load(strXMLFile)
					hs.SaveINISetting("Debug","ErrorCodeWWO",xmlfile.parseError.errorcode,sINI)
					if xmlfile.parseError.errorcode <> 0 Then
						fs.Add("There was an error with the XML file.  Error Reason: ")
						fs.Add(xmlfile.parseError.reason)
						hs.WriteLog(IName,fs.Value)
						fs.Reset
						dRun = dRun.addMinutes(-30)
						hs.SaveINISetting("Settings","lastranWWO",dRun,sINI)
						hs.SaveINISetting("Debug","ErrorReasonWWO",xmlfile.parseError.reason,sINI)
						hs.SaveINISetting("Debug","ErrorTimeWWO",trim(Now()),sINI)
					End if
					if xmlfile.parseError.errorcode = 0 Then
						getINIValues()
						oNodeList = xmlfile.getElementsByTagName("current_condition")
							oNode = oNodeList.nextNode
								if len(trim(hs.GetINISetting("Settings","updlocation","",sINI))) > 0 Then
									hs.SaveINISetting("Location","CityState",trim(hs.GetINISetting("Settings","updlocation","",sINI)),sINI)
								Else
									xNode = oNode.selectSingleNode("location")
									if NOT xNOde Is Nothing Then
										hs.SaveINISetting("Location","CityState",oNode.selectSingleNode("location").Text,sINI)
									Else
										hs.SaveINISetting("Location","CityState",hs.GetINISetting("Settings","updlocation","",sINI),sINI)
									End if
								End if
								Try
									sLastUp = oNode.selectSingleNode("observation_time").Text
									fs.Add(formatDateTime(dTemp,2))
									fs.Add(", ")
									fs.Add(sLastUp)
									hs.SaveINISetting ("Location","TimeChecked",fs.Value,sINI)
									fs.Reset
									' Last Updated
									setDeviceUpdated(sLastUp,sLastUp)
								Catch ex as Exception
									hs.WriteLog(IName,"Error with observation time: " & ex.Message)
								End Try
								Try
									' Current Temp
									if unitTemp = "F" Then
										curTemp = oNode.selectSingleNode("temp_F").Text
									Else
										curTemp = oNode.selectSingleNode("temp_C").Text
									End if
									' Check the temp for daily hi low values
									setDailyHiLow(curTemp)
								Catch ex as Exception
									hs.WriteLog(IName,"Error with current temperature: " & ex.Message)
								End Try
								Try
									' Humidity
									xNode = oNode.selectSingleNode("humidity")
									if Not xNode Is Nothing Then
										wcHum = oNode.selectSingleNode("humidity").Text
										setDeviceHumidity(wcHum)
										bRh = True
									Else
										setDeviceHumidity("")
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error with humidity: " & ex.Message)
								End Try
								Try
									' Wind Gust
									setDeviceWindGust("N/A")
									' Wind Degrees
									setDeviceWindDeg(oNode.selectSingleNode("winddirDegree").text)
								Catch ex as Exception
									hs.WriteLog(IName,"Error with wind degrees: " & ex.Message)
								End Try
								Try
									' Wind Direction
									sWindDir = hs.RunEx("AZ_weatherXML_web.vb","windDirImage",oNode.selectSingleNode("winddir16Point").text,True) 
									setDeviceWindDir(sWindDir)
								Catch ex as Exception
									hs.WriteLog(IName,"Error with wind direction: " & ex.Message)
								End Try
								Try
									' Wind Speed
									xNode = oNode.selectSingleNode("windspeedMiles")
									if Not xNode Is Nothing Then
										wcWind = oNode.selectSingleNode("windspeedMiles").text
										if hs.GetINISetting("InfoUnit","speedUnit","mph",sINI) = "kmph" Then
											wKWind = convertMPH(wcWind)
										Else 
											wkWind = wcWind
										End if
										setDeviceWindSpeed(wkWind)
										bWd = True
									Else
										setDeviceWindSpeed("")
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error with wind speed: " & ex.Message)
								End Try
								Try
									' Feel like
									feelLike = "N/A"
									if uCase(unitTemp) = "F" Then
										xNode = oNode.selectSingleNode("windchill_f")
										xNode2 = oNode.selectSingleNode("heat_index_f")
									Else
										xNode = oNode.selectSingleNode("windchill_c")
										xNode2 = oNode.selectSingleNode("heat_index_c")
									End if
									if xNode Is Nothing AND xNode2 Is Nothing Then
										bChk = True
									Else
										bChk = true
										if curTemp > 80 Then
											if Not xNode2 Is Nothing THen
												if uCase(unitTemp) = "F" Then
													feelLike = oNode.selectSingleNode("heat_index_f").text
													if isNumeric(feelLike) Then
														bChk = false
													End if
												Else
													feelLike = oNode.selectSingleNode("heat_index_c").text
													if isNumeric(feelLike) Then
														bChk = false
													End if
												End if
											End if
										Else
											if Not xNode Is Nothing Then
												if uCase(unitTemp) = "F" Then
													feelLike = oNode.selectSingleNode("windchill_f").text
													if isNumeric(feelLike) Then
														bChk = false
													End if
												Else
													feelLike = oNode.selectSingleNode("windchill_c").text
													if isNumeric(feelLike) Then
														bChk = false
													End if
												End if
											End if
										End if
									End if
									if bChk = true Then
										if uCase(unitTemp) = "F" Then
											wcTemp = curTemp 
										Else
											wcTemp = curTemp*(9/5)+32
										End if
										if isNumeric(wcTemp) Then
											feelLike = getFeelsLike(wcTemp,wcWind,wcHum)
											if isNumeric(feelLike) Then
												if uCase(unitTemp) <> "F" Then
													feelLike = (feelLike-32)/9*5
												End if
											End if
										End if
									End if
									' Feels Like
									setDeviceLike(feelLike)
								Catch ex as Exception
									hs.WriteLog(IName,"Error with feels like: " & ex.Message)
								End Try
								Try
									' Current Temperature
									setDeviceTemp(curTemp,feelLike)
									' Condition & Condition Icon
									sImage = oNode.selectSingleNode("weatherIconUrl").Text
									setDeviceCondition(oNode.selectSingleNode("weatherDesc").Text,sImage)
									' Condition Image
									setDeviceCondImage()
								Catch ex as Exception
									hs.WriteLog(IName,"Error with condition icon: " & ex.Message)
								End Try
								Try
									' Dewpoint
									setDeviceDoTheDew("")
									' Barometer
									if hs.GetINISetting ("InfoUnit","pressureUnit","i",sINI) = "i" Then
										xNode = oNode.selectSingleNode("inches")
									Else
										xNode = oNode.selectSingleNode("pressure")
									End if
									if Not xNode Is Nothing Then
										if hs.GetINISetting ("InfoUnit","pressureUnit","i",sINI) = "i" Then
											cBar = oNode.selectSingleNode("inches").text
										Else
											cBar = oNode.selectSingleNode("pressure").text
										End if
										setDeviceBarometer(cBar,"")
									Else
										setDeviceBarometer("","")
									End if
								Catch ex as Exception
									hs.WriteLog(IName,"Error with barometer: " & ex.Message)
								End Try
								Try
									' Visibility
									sVisible = oNode.selectSingleNode("visibility").Text
									if hs.GetINISetting("InfoUnit","distanceUnit","m",sINI) = "m" Then
										sVisible = oNode.selectSingleNode("visibility").Text
										if isNumeric(sVisible) Then
											nVisible = sVisible*0.621371192 
											sVisible = nVisible.toString("0.0")
										End if
									End if
									setDeviceVisibility(sVisible)
								Catch ex as Exception
									hs.WriteLog(IName,"Error with visibility: " & ex.Message)
								End Try
' Start Forecast Here								
						hs.Runex("AZ_weatherXML_wu.vb","clearINIData",10,True)
						hs.Runex("AZ_weatherXML_wu.vb","clearOldINIData",20,True)
						hs.Runex("AZ_weatherXML_wu.vb","setDeviceForecastClear","",True)
						y = 1
						oNodeList = xmlfile.getElementsByTagName("./data/weather")
							for x = 0 to oNodeList.Length-1
								oNode = oNodeList.nextNode
								xNode = oNode.selectSingleNode("date")
								if NOT xNode Is Nothing Then
									sDay = oNode.selectSingleNode("date").text
									fs.Add("DayDate")
									fs.Add(x+1)
									hs.SaveINISetting("Forecast",fs.Value,sDay,sINI)
									fs.Reset
									fs.Add("DayName")
									fs.Add(x+1)
									hs.SaveINISetting("Forecast",fs.Value,cDate(sDay).toString("dddd"),sINI)
									fs.Reset
								Else
									fs.Add("DayDate")
									fs.Add(x+1)
									hs.SaveINISetting("Forecast",fs.Value,"",sINI)
									fs.Reset
									fs.Add("DayName")
									fs.Add(x+1)
									hs.SaveINISetting("Forecast",fs.Value,"",sINI)
									fs.Reset
								End if
								if unitTemp = "F" Then
									xNode = oNode.selectSingleNode("tempMaxF")
								Else
									xNode = oNode.selectSingleNode("tempMaxC")
								End if
								if NOT xNode Is Nothing Then
									if unitTemp = "F" Then
										sValue = oNode.selectSingleNode("tempMaxF").text
									Else
										sValue = oNode.selectSingleNode("tempMaxC").text
									End if
									fs.Add("DayHi")
									fs.Add(x+1)
									hs.SaveINISetting("Forecast",fs.Value,sValue,sINI)
									fs.Reset
								Else
									fs.Add("DayHi")
									fs.Add(x+1)
									hs.SaveINISetting("Forecast",fs.Value,"",sINI)
									fs.Reset
								End if
								if unitTemp = "F" Then
									xNode = oNode.selectSingleNode("tempMaxF")
								Else
									xNode = oNode.selectSingleNode("tempMaxC")
								End if
								if NOT xNode Is Nothing Then
									if unitTemp = "F" Then
										sValue = oNode.selectSingleNode("tempMinF").text
									Else
										sValue = oNode.selectSingleNode("tempMinC").text
									End if
									fs.Add("DayLow")
									fs.Add(x+1)
									hs.SaveINISetting("Forecast",fs.Value,sValue,sINI)
									fs.Reset
								Else
									fs.Add("DayLow")
									fs.Add(x+1)
									hs.SaveINISetting("Forecast",fs.Value,"",sINI)
									fs.Reset
								End if
								xNode = oNode.selectSingleNode("weatherDesc")
								if Not xNode Is Nothing Then
									fs.Add("DayCondition")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,oNode.selectSingleNode("weatherDesc").text,sINI)
									fs.Reset
								Else
									fs.Add("DayCondition")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,"",sINI)
									fs.Reset
								End if
								xNode = oNode.selectSingleNode("weatherIconUrl")
								if Not xNode Is Nothing Then
									fs.Add("DayIcon")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,oNode.selectSingleNode("weatherIconUrl").text,sINI)
									fs.Reset
									fs.Add("DayIconName")
									fs.Add(x+1)
									sIconName = hs.RunEx("AZ_weatherXML_wu.vb","saveIcon",oNode.selectSingleNode("weatherIconUrl").text,True)
									hs.SaveINISetting("forecast",fs.Value,sIconName,sINI)
									fs.Reset
								Else
									fs.Add("DayIcon")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,"",sINI)
									fs.Reset
									fs.Add("DayIconName")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,"",sINI)
									fs.Reset
								End if
								xNode = oNode.selectSingleNode("precipMM")
								if Not xNode Is Nothing Then
									fs.Add("DayPrecipitation")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,oNode.selectSingleNode("precipMM").text,sINI)
									fs.Reset
								Else
									fs.Add("DayPrecipitation")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,"",sINI)
									fs.Reset
								End if
								xNode = oNode.selectSingleNode("windspeedMiles")
								if Not xNode Is Nothing Then
									fs.Add("windSpeed")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,oNode.selectSingleNode("windspeedMiles").text,sINI)
									fs.Reset
								Else
									fs.Add("windSpeed")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,"",sINI)
									fs.Reset
								End if
								xNode = oNode.selectSingleNode("winddir16Point")
								if Not xNode Is Nothing Then
									fs.Add("windDir")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,oNode.selectSingleNode("winddir16Point").text,sINI)
									fs.Reset
								Else
									fs.Add("windDir")
									fs.Add(x+1)
									hs.SaveINISetting("forecast",fs.Value,"",sINI)
									fs.Reset
								End if
								fs.Add("NightCondition")
								fs.Add(x+1)
								hs.SaveINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								fs.Add("NightPrecipitation")
								fs.Add(x+1)
								hs.SaveINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								fs.Add("NightForecast")
								fs.Add(x+1)
								hs.SaveINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								fs.Add("NightIcon")
								fs.Add(x+1)
								hs.SaveINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								fs.Add("NightIconName")
								fs.Add(x+1)
								hs.SaveINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								fs.Add("DayCondition")
								fs.Add(x+1)
								sCond = hs.GetINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								fs.Add("DayHi")
								fs.Add(x+1)
								sHigh = hs.GetINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								fs.Add("DayLow")
								fs.Add(x+1)
								sLow = hs.GetINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								fs.Add("windSpeed")
								fs.Add(x+1)
								sWndSpd = hs.GetINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								fs.Add("windDir")
								fs.Add(x+1)
								sWndDir = hs.GetINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								fs.Add("DayName")
								fs.Add(x+1)
								sDayName = hs.GetINISetting("forecast",fs.Value,"",sINI)
								fs.Reset
								if y = 1 Then 
									sDayText = "Vandaag"
								Elseif y = 2 Then
									sDayText = "Vannacht"
								Elseif y = 3 Then
									sDayText = "Morgen"
								Elseif y = 4 Then
									sDayText = "Morgennacht"
								Else
									if y MOD 2 = 0 Then
										fs.Add(sDayName)
										fs.Add(" Nacht")
										sDayText = fs.Value
										fs.Reset
									Else
										sDayText = sDayName
									End if
								End if
								fs.Add(sDayText)
								fs.Add(": ")
								'fs.Add(sCond)
						'dim dayCond
						'dayCond = hs.GetINISetting ("Forecast","DayCondition" & x,"",sINI)
						fs.Add(lcase(hs.GetINISetting("Language Conditions",sCond,sCond,sINI)))
								fs.Add(", met als hoogste nabij ")
								fs.Add(sHigh)
								fs.Add(". ")
								if len(trim(sWndSpd)) > 0 Then
									if isNumeric(sWndSpd) AND sWndSpd > 0 Then
										fs.Add("Wind uit de richting ")
										fs.Add(directionText(sWindDir))
										fs.Add(" met ")
										fs.Add(sWndSpd)
										fs.Add(" ")
										fs.Add(hs.GetINISetting("InfoUnit","Speed","mijlen per uur",sINI))
										fs.Add(".  ")
									End if
								End if
								sValue = fs.Value
								fs.Reset
								fs.Add("ExtForecast")
								fs.Add(y)
								hs.SaveINISetting("WeatherCom_ExtForecast",fs.Value,sValue,sINI)
								y = y + 1
								fs.Reset
								if y = 1 Then 
									sDayText = "Vandaag"
								Elseif y = 2 Then
									sDayText = "Vannacht"
								Elseif y = 3 Then
									sDayText = "Morgen"
								Elseif y = 4 Then
									sDayText = "Morgennacht"
								Else
									if y MOD 2 = 0 Then
										fs.Add(sDayName)
										fs.Add(" Nacht")
										sDayText = fs.Value
										fs.Reset
									Else
										sDayText = sDayName
									End if
								End if
								fs.Add(sDayText)
								fs.Add(": ")
								fs.Add("Het laagste is ongeveer ")
								fs.Add(sLow)
								fs.Add(".  ")
								sValue = fs.Value
								fs.Reset
								fs.Add("ExtForecast")
								fs.Add(y)
								hs.SaveINISetting("WeatherCom_ExtForecast",fs.Value,sValue,sINI)
								y = y + 1
								fs.Reset
							Next
						oNodeList = Nothing		
					End if
					setDeviceForecast()
			xmlfile = Nothing
		fs = Nothing
		if debugMode = True Then
			hs.WriteLog(IName,"Finished importing weather information from WWO.")
		End if
	Catch e as Exception
		hs.WriteLog(IName,"weatherWWOData: " & e.message)
	End Try
End Sub

Function XMLFileExists(ByVal sXMLName as String) as Boolean
	Dim bAnswer as boolean
	Dim fs, FSO as Object
	Try
		debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
		fs = hs.CreateStringClass
			FSO = CreateObject("Scripting.FileSystemObject")
				if NOT FSO.FileExists(sXMLName) Then
					fs.Add("The ")
					fs.Add(sXMLName)
					fs.Add(" file is missing.  Unable to continue the data import.")
					hs.WriteLog(IName,fs.Value)
					fs.Reset
					bAnswer = false
				Else	
					if debugMode = True Then
						fs.Add("The file ")
						fs.Add(sXMLName)
						fs.Add(" is ready for import.")
						hs.WriteLog(IName,fs.Value)
					End if
					bAnswer = True
				End if
			FSO = Nothing
		fs = Nothing
	Catch e as Exception
		hs.Writelog(IName,"XMLFileExists: " & e.Message)
	End Try
	Return bAnswer
End Function
