﻿'++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
' script: weathercom_xml_speak.vb
' Revision	Date		Programmer		Comment
' 1.3		09/04/2011	CFGuy			Modified spoken text.  Added option to save spoken text to virtual device.
' 1.2  		2009/01/31	dmurphy			Bug Fix.
' 1.1  		2009/01/31 	dmurphy			VB.Net Version
' Functions/Subs
' Main - main speak function
' dayString - Converts abbreviated months and day to spelled out.  ex Oct 9 becomes October Ninth
' directionText - takes the abbreviated direction and returns a speak able phrase
' normalHigh - builds the speak string for the normal high for today
' normalLow - builds the speak string for the normal low for today
' recordHigh - builds the speak string for the record high for today
' recordLow - builds the speak string for the record low for today
' reSpeak - repeats the string in the last spoken virtual device
' tempAveString - takes a temperature and changes it to a range.
' timeString - Converts time to speak ready format.
' weatherBarometer - builds the speak string for the current barometer value
' weatherCondition - builds the speak string for the current condition
' weatherDewpoint - builds the speak string for the current dewpoint
' weatherForecast - builds the speak string for the Forecast
' weatherHiLow - checks the current weather to save in daily hi low values
' weatherHumidity - builds the speak string for the current humidity
' weatherTemp - builds the speak string for the current temperature
' weatherTempDay - builds the speak string for a particular days temperature
' weatherUpdated - builds the speak string for the last updated values
' weatherVisibility - builds the speak string for the current visibility
' weatherWind - builds the speak string for the current wind conditions
'++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Option Strict On
Option Explicit On
Imports VB = Microsoft.VisualBasic
Imports System.IO
Dim sINI as String = "weathercom_xml.ini"
Dim sVirtualDevice as String
Public Dim IName as String = "weatherXML_Speak"
Public Dim debugMode As Boolean = False
'++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Sub Main(Optional ByVal bSpeak As String = "True")
    Dim intSpeakAny as Integer = 0
	Dim x as Integer
	Dim ss, st as Object
    Dim sVirtualDevice, sHosts, devUpdatedSpk, devConditionSpk, devTempSpk, devFeelsLikeSpk, devHiTempSpk, devLowTempSpk, devTempHistorySpk, devTempHistoryLowSpk as String
	Dim devTempRecordHighSpk, devTempRecordLowSpk, devTempLastYearHighSpk, devTempLastYearLowSpk, devHumiditySpk, devWindSpk, devWindDirSpk, devWindGustSpk as String
	Dim devWindDegreesSpk, devVisibilitySpk, devDewpointSpk, devBarometerSpk, devBarometerDirSpk, devMoonPhaseSpk, devForecastSpk, devForecastdays as String
	Dim sVisibility, strWindSpeed, strWindDirection, strWindgust, strWindDegrees, strDoTheDew, strBarometer, sForecast, speakFirst, sHiLow as String
	Dim sValue, tempString, updString, likeString, curString, condition, sHumidity as String
	if len(trim(bSpeak)) = 0 Then
		bSpeak = True
	End if
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	sVirtualDevice = hs.GetINISetting("Settings","lastSpoken","",sINI)
	sHosts = hs.GetINISetting("Speak","Hosts","",sINI)
	' Check Device Speak Settings    
	devUpdatedSpk = hs.GetINISetting ("Settings","devUpdatedSpk","0",sINI)
    devConditionSpk = hs.GetINISetting("Settings","devConditionSpk","0",sINI)
    devTempSpk = hs.GetINISetting("Settings","devTempSpk","0",sINI)
    devFeelsLikeSpk = hs.GetINISetting("Settings","devFeelsLikeSpk","0",sINI)
	devHiTempSpk = hs.GetINISetting("Settings","devHiTempSpk","0",sINI)
	devLowTempSpk = hs.GetINISetting("Settings","devLowTempSpk","0",sINI)
	devTempHistorySpk = hs.GetINISetting("Settings","devTempHistorySpk","0",sINI)
	devTempHistoryLowSpk = hs.GetINISetting("Settings","devTempHistorySpk","0",sINI)
	devTempRecordHighSpk = hs.GetINISetting("Settings","devTempRecordHighSpk","0",sINI)
	devTempRecordLowSpk = hs.GetINISetting("Settings","devTempRecordLowSpk","0",sINI)
	devTempLastYearHighSpk = hs.GetINISetting("Settings","devTempLastYearHighSpk","0",sINI)
	devTempLastYearLowSpk = hs.GetINISetting("Settings","devTempLastYearLowSpk","0",sINI)
    devHumiditySpk = hs.GetINISetting("Settings","devHumiditySpk","0",sINI)
    devWindSpk = hs.GetINISetting("Settings","devWindSpk","0",sINI)
    devWindDirSpk = hs.GetINISetting("Settings","devWindDirSpk","0",sINI)
    devWindGustSpk = hs.GetINISetting ("Settings","devWindGustSpk","0",sINI)
    devWindDegreesSpk = hs.GetINISetting ("Settings","devWindDegreesSpk","0",sINI)
    devVisibilitySpk = hs.GetINISetting("Settings","devVisibilitySpk","0",sINI)
    devDewpointSpk = hs.GetINISetting("Settings","devDewpointSpk","0",sINI)
    devBarometerSpk = hs.GetINISetting("Settings","devBarometerSpk","0",sINI)
    devBarometerDirSpk = hs.GetINISetting ("Settings","devBarometerDirSpk","0",sINI)
	devMoonPhaseSpk = hs.GetINISetting("Settings","devMoonPhaseSpk","0",sINI)	
    devForecastSpk = hs.GetINISetting("Settings","devForecastSpk","0",sINI)
    devForecastdays = hs.GetINISetting("Settings","devForecastdays","",sINI)
	speakFirst = hs.GetINISetting("Speak","speakFirst","",sINI)
    if (devUpdatedSpk = "1" OR devConditionSpk = "1" OR devTempSpk = "1" OR devFeelsLikeSpk = "1" OR devHiTempSpk = "1" OR devLowTempSpk = "1" OR devTempHistorySpk = "1" OR devTempHistoryLowSpk = "1"  OR devTempRecordHighSpk = "1" OR devTempRecordLowSpk = "1" OR devTempLastYearHighSpk = "1" OR devTempLastYearLowSpk = "1" OR devHumiditySpk = "1"  OR devWindSpk = "1" OR devWindDirSpk = "1" OR devWindGustSpk = "1" OR devWindDegreesSpk = "1" OR devVisibilitySpk = "1" OR devDewpointSpk = "1" OR devBarometerSpk = "1" OR devBarometerDirSpk = "1" OR devMoonPhaseSpk = "1" OR devForecastSpk = "1") Then
        intSpeakAny = 1
    End if
    if intSpeakAny = 0 Then
        Exit Sub
    End if
	ss = hs.CreateStringClass
	st = hs.CreateStringClass
		if devUpdatedSpk = "1" Then
			updString = weatherUpdated()
			if len(trim(updString)) > 0 Then
				ss.Add(updString)
				st.Add(updString)
			End if
		End if
		if devConditionSpk = "1" Then
			condition = weatherCondition()
			if len(trim(condition)) > 0 Then
				ss.Add(condition)
				st.Add(condition)
			End if
		End If
		if devTempSpk = "1" AND devFeelsLikeSpk = "1" Then
			curString = weatherTemp("both")
			if len(trim(curString)) > 0 Then
				ss.Add(curString)
				st.Add(curString)
			End if
		Else
			if devTempSpk = "1" OR devFeelsLikeSpk = "1" Then
				if devTempSpk = "1" Then
					curString = weatherTemp("current")
					if len(trim(curString)) > 0 Then
						ss.Add(curString)
						st.Add(curString)
					End if
				End if
				if devFeelsLikeSpk = "1" Then
					likeString = weatherTemp("feels")
					if len(trim(likeString)) > 0 Then
						ss.Add(likeString)
						st.Add(likeString)
					End if
				End if
			End if
		End if
		if devHiTempSpk = "1" OR devLowTempSpk = "1" Then
			if devHiTempSpk = "1" AND devLowTempSpk = "1" Then
				sHiLow = "both"
			Elseif devHiTempSpk = "1" Then
				sHiLow = "high"
			Elseif devLowTempSpk = "1" Then
				sHiLow = "low"
			End if
			tempString = weatherHiLow(sHiLow)
			if len(trim(tempString)) > 0 Then
				ss.Add(tempString)
				st.Add(tempString)
			End if
		End if
		if devTempHistorySpk = "1" Then
			sValue = normalHigh()
			if len(trim(sValue)) > 0 Then
				ss.Add(sValue)
				st.Add(sValue)
			End if
		End if
		if devTempHistoryLowSpk = "1" Then
			sValue = normalLow()
			if len(trim(sValue)) > 0 Then
				ss.Add(sValue)
				st.Add(sValue)
			End if
		End if
		if devTempRecordHighSpk = "1" Then
			sValue = recordHigh()
			if len(trim(sValue)) > 0 Then
				ss.Add(sValue)
				st.Add(sValue)
			End if
		End if
		if devTempRecordLowSpk = "1" Then
			sValue = recordLow()
			if len(trim(sValue)) > 0 Then
				ss.Add(sValue)
				st.Add(sValue)
			End if
		End if
		if devTempLastYearHighSpk = "1" Then
			sValue = lastYearHigh()
			if len(trim(sValue)) > 0 Then
				ss.Add(sValue)
				st.Add(sValue)
			End if
		End if
		if devTempLastYearLowSpk = "1" Then
			sValue = lastYearLow()
			if len(trim(sValue)) > 0 Then
				ss.Add(sValue)
				st.Add(sValue)
			End if
		End if
		if devHumiditySpk = "1" Then
			sHumidity = weatherHumidity()
			if len(trim(sHumidity)) > 0 Then
				ss.Add(sHumidity)
				st.Add(sHumidity)
			End if
		End If
		if devWindSpk = "1" AND devWindDirSpk = "1" AND devWindGustSpk = "1" AND devWindDegreesSpk = "1" Then
			strWindSpeed = weatherWind("all")
			ss.Add(strWindSpeed)
			st.Add(strWindSpeed)
		Else
			if devWindSpk = "1" Then
				strWindSpeed = weatherWind("wind")
				if len(trim(strWindSpeed)) > 0 Then
					ss.Add(strWindSpeed)
					st.Add(strWindSpeed)
				End if
			End if
			if devWindDirSpk = "1" Then
				strWindDirection = weatherWind("direction")
				if len(trim(strWindDirection)) > 0 Then
					ss.Add(strWindDirection)
					st.Add(strWindDirection)
				End if
			End if
			if devWindGustSpk = "1" Then
				strWindgust = weatherWind("gust")
				if len(trim(strWindgust)) > 0 Then
					ss.Add(strWindgust)
					st.Add(strWindgust)
				End if
			End if
			if devWindDegreesSpk = "1" Then
				strWindDegrees = weatherWind("degrees")
				if len(trim(strWindDegrees)) > 0 Then
					ss.Add(strWindDegrees)
					st.Add(strWindDegrees)
				End if
			End if
		End If
		if devVisibilitySpk = "1" Then
			sVisibility = weatherVisibility()
			if len(trim(sVisibility)) > 0 Then
				ss.Add(sVisibility)
				st.Add(sVisibility)
			End if
		End If
		if devDewpointSpk = "1" Then
			strDoTheDew = weatherDewpoint()
			if len(trim(strDoTheDew)) > 0 Then
				ss.Add(strDoTheDew)
				st.Add(strDoTheDew)
			End If
		End if
		if devBarometerSpk = "1" AND devBarometerDirSpk = "1" Then
			strBarometer = weatherBarometer("both")
			ss.Add (strBarometer)
			st.Add(strBarometer)
		Else
			if devBarometerSpk = "1" Then
				strBarometer = weatherBarometer("barometer")
				ss.Add (strBarometer)
				st.Add(strBarometer)
			End if
			if devBarometerDirSpk = "1" Then
				strBarometer = weatherBarometer("direction")
				ss.Add(strBarometer)
				st.Add(strBarometer)
			End if
		End If
		if devMoonPhaseSpk = "1" Then
			sValue = moonPhase()
			if len(trim(sValue)) > 0 Then
				ss.Add(sValue)
				st.Add(sValue)
			End if
		End if
		if devForecastSpk = "1" Then
			sForecast = weatherForecast("All")
			if len(trim(sForecast)) > 0 Then
				ss.Add (sForecast)
				st.Add(sForecast)
			End if
		End If
		if len(st.Value) > 0 Then		
			if len(trim(sVirtualDevice)) > 0 Then
				hs.SetDeviceString(sVirtualDevice, st.Value, true)
				hs.SaveINISetting("WeatherInfo","lastSpoke",Trim(st.Value),sINI)
			End if
		End if
		if len(ss.Value) > 0 AND bSpeak = "True" Then
			st.Reset
			st.Add(speakFirst)
			st.Add("  ")
			st.Add(ss.Value)
			hs.speak(st.Value,false,sHosts)
			ss.Reset
		End if
	st = Nothing
	ss = Nothing
	if debugMode = true Then
		hs.WriteLog(Iname,"Finished running weathercom_xml_speak.vb")
	End if
End Sub

Function dayString(ByVal sDate as String) as String
	Dim aDate as Array
	Dim ds as Object
	Dim rtS, sMonth, sDay as String
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	rtS = ""
	Try
		if debugMode = True Then
			hs.WriteLog(Iname,"dayString: " & sDate)
		End if
		if NOT isDate(sDate) Then
			return sDate
			Exit Function
		End if
		aDate = split(sDate,",")
		sDate = aDate(0)
		sMonth = Month(sDate)
		sDay = Day(sDate)
		ds = hs.CreateStringClass
			Select Case lCase(sMonth)
				Case "jan","january","1"
					ds.Add("Januari ")
				Case "feb","february","2"
					ds.Add("Februari ")
				Case "mar","march","3"
					ds.Add("Maart ")
				Case "apr","april","4"
					ds.Add("April ")
				Case "may","5"
					ds.Add("Mei ")
				Case "jun","june","6"
					ds.Add("Juni ")
				Case "jul","july","7"
					ds.Add("Juli ")
				Case "aug","august","8"
					ds.Add("Augustus ")
				Case "sep","september","9"
					ds.Add("September ")
				Case "oct","october","10"
					ds.Add("October ")
				Case "nov","november","11"
					ds.Add("November ")
				Case "dec","december","12"
					ds.Add("December ")
			End Select
			Select Case sDay
				Case 1
					ds.Add("eerste")
				Case 2
					ds.Add("tweede")
				Case 3
					ds.Add("derde")
				Case 4
					ds.Add("vierde")
				Case 5
					ds.Add("vijfde")
				Case 6
					ds.Add("zesde")
				Case 7
					ds.Add("zevende")
				Case 8
					ds.Add("achtste")
				Case 9
					ds.Add("negende")
				Case 10
					ds.Add("tiende")
				Case 11
					ds.Add("elfde")
				Case 1
					ds.Add("twaalfde")
				Case 13
					ds.Add("dertiende")
				Case 14
					ds.Add("viertiende")
				Case 15
					ds.Add("vijftiende")
				Case 16
					ds.Add("zestiende")
				Case 17
					ds.Add("zeventiende")
				Case 18
					ds.Add("achttiende")
				Case 19
					ds.Add("negentiende")
				Case 20
					ds.Add("twintigste")
				Case 21
					ds.Add("een en twintigste")
				Case 22
					ds.Add("twee en twintigste")
				Case 23
					ds.Add("drie en twintigste")
				Case 24
					ds.Add("vier en twintigste")
				Case 25
					ds.Add("vijf en twintigste")
				Case 26
					ds.Add("zes en twintigste")
				Case 27
					ds.Add("zeven en twintigste")
				Case 28
					ds.Add("acht en twintigste")
				Case 29
					ds.Add("negen en twintigste")
				Case 30
					ds.Add("dertigste")
				Case 31
					ds.Add("een en dertigste")
			End Select
			rtS = ds.Value
		ds = Nothing
	Catch e as Exception
		hs.WriteLog(IName,"dayString: " & e.message)
	End Try
	Return rtS
End Function

Function directionText(ByVal strDirection As String) As String
    Dim txt As String
    Select Case UCase(trim(strDirection))
        Case "E"
            txt = "Oost"
        Case "ENE"
            txt = "Oost Noordoost"
        Case "ESE"
            txt = "Oost Zuidoost"
        Case "N"
            txt = "Noord"
        Case "NE"
            txt = "Noordoost"
        Case "NNE"
            txt = "Noord Noordoost"
        Case "NNW"
            txt = "Noord Noordwest"
        Case "NW"
            txt = "Noordwest"
        Case "S"
            txt = "Zuid"
        Case "SE"
            txt = "Zuidoost"
        Case "SSE"
            txt = "Zuid Zuidoost"
        Case "SSW"
            txt = "Zuid Zuidwest"
        Case "SW"
            txt = "Zuidwest"
        Case "W"
            txt = "West"
        Case "WNW"
            txt = "West Nordwest"
        Case "WSW"
            txt = "West Zuidwest"
        Case Else
            txt = strDirection
    End Select
    Return txt
End Function

Function lastYearHigh(Optional ByVal sParam as String = "")
	Dim nh as Object
	Dim rtS as String = ""
	Dim sValue, unitTemp as String
	nh = hs.CreateStringClass
		debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
		unitTemp = hs.GetINISetting ("InfoUnit","TempSpeak","",sINI)
		sValue = hs.GetINISetting("WeatherInfo","TempYearAgoHigh","",sINI)
		if len(trim(sValue)) > 0 Then
			nh.Add("Vorig jaar om deze tijd was de hoogste temperatuur ")
			nh.Add(sValue)
			nh.Add(" graden ")
			if len(trim(unitTemp)) > 0 Then
				nh.Add(unitTemp)
			End if
			nh.Add(".  ")
			rtS = nh.Value
		End if
	nh = nothing
	return rtS
End Function

Function lastYearLow(Optional ByVal sParam as String = "")
	Dim nh as Object
	Dim rtS as String = ""
	Dim sValue, unitTemp as String
	nh = hs.CreateStringClass
		debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
		unitTemp = hs.GetINISetting ("InfoUnit","TempSpeak","",sINI)
		sValue = hs.GetINISetting("WeatherInfo","TempYearAgoLow","",sINI)
		if len(trim(sValue)) > 0 Then
			nh.Add("Vorig jaar op deze dag was de laagste temperatuur ")
			nh.Add(sValue)
			nh.Add(" graden ")
			if len(trim(unitTemp)) > 0 Then
				nh.Add(unitTemp)
			End if
			nh.Add(".  ")
			rtS = nh.Value
		End if
	nh = nothing
	return rtS
End Function

Function moonPhase(Optional ByVal sParam as String = "")
	Dim nh as Object
	Dim dtStart as Date = Now
   	Dim NMoon, FMoon as Date
   	Dim CurCycle as Integer
   	Dim sDesc as String = ""
	Dim rtS as String = ""
	Dim sValue as String
	nh = hs.CreateStringClass
		debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
		sValue = hs.GetINISetting("WeatherInfo","moonPhaseTxt","",sINI)
		hs.Moon(dtStart, NMoon, FMoon, CurCycle, sDesc)
		if len(trim(sValue)) > 0 Then
			nh.Add("De maanfase is vannacht ")
			nh.Add(sValue)
			nh.Add(".  De volgende volle maan is op ")
			nh.Add(dayString(NMoon.ToShortDateString))
			nh.Add(".  ")
			rtS = nh.Value
		End if
	nh = nothing
	return rtS
End Function

Function normalHigh(Optional ByVal sParam as String = "")
	Dim nh as Object
	Dim rtS as String = ""
	Dim sValue, unitTemp as String
	nh = hs.CreateStringClass
		debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
		unitTemp = hs.GetINISetting ("InfoUnit","TempSpeak","",sINI)
		sValue = hs.GetINISetting("WeatherInfo","TempLastYearHigh","",sINI)
		if len(trim(sValue)) > 0 Then
			nh.Add("De verwacht hoogste temperatuur voor vandaag is ")
			nh.Add(sValue)
			nh.Add(" graden ")
			if len(trim(unitTemp)) > 0 Then
				nh.Add(unitTemp)
			End if
			nh.Add(".  ")
			rtS = nh.Value
		End if
	nh = nothing
	return rtS
End Function

Function normalLow(Optional ByVal sParam as String = "")
	Dim nh as Object
	Dim rtS as String = ""
	Dim sValue, unitTemp as String
	nh = hs.CreateStringClass
		debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
		unitTemp = hs.GetINISetting ("InfoUnit","TempSpeak","",sINI)
		sValue = hs.GetINISetting("WeatherInfo","TempLastYearLow","",sINI)
		if len(trim(sValue)) > 0 Then
			nh.Add("De verwacht laagste temperatuur voor vandaag is ")
			nh.Add(sValue)
			nh.Add(" graden ")
			if len(trim(unitTemp)) > 0 Then
				nh.Add(unitTemp)
			End if
			nh.Add(".  ")
			rtS = nh.Value
		End if
	nh = nothing
	return rtS
End Function

Function recordHigh(Optional ByVal sParam as String = "")
	Dim nh as Object
	Dim rtS as String = ""
	Dim sValue, sYear, unitTemp as String
	nh = hs.CreateStringClass
		debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
		unitTemp = hs.GetINISetting ("InfoUnit","TempSpeak","",sINI)
		sValue = hs.GetINISetting("WeatherInfo","TempRecordHigh","",sINI)
		sYear = hs.GetINISetting("WeatherInfo","TempRecordHighYear","",sINI)
		if len(trim(sValue)) > 0 Then
			nh.Add("De hoogste temperatuur gehaald op deze dag was ")
			nh.Add(sValue)
			nh.Add(" graden ")
			if len(trim(unitTemp)) > 0 Then
				nh.Add(unitTemp)
			End if
			nh.Add(" en dat gebeurde in het jaar ")
			nh.Add(sYear)
			nh.Add(".  ")
			rtS = nh.Value
		End if
	nh = nothing
	return rtS
End Function

Function recordLow(Optional ByVal sParam as String = "")
	Dim rl as Object
	Dim rtS as String = ""
	Dim sValue, sYear, unitTemp as String
	rl = hs.CreateStringClass
		debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
		unitTemp = hs.GetINISetting ("InfoUnit","TempSpeak","",sINI)
		sValue = hs.GetINISetting("WeatherInfo","TempRecordLow","",sINI)
		sYear = hs.GetINISetting("WeatherInfo","TempRecordLowYear","",sINI)
		if len(trim(sValue)) > 0 Then
			rl.Add("De laagste temperatuur ooit op deze dag was ")
			rl.Add(sValue)
			rl.Add(" graden ")
			if len(trim(unitTemp)) > 0 Then
				rl.Add(unitTemp)
			End if
			rl.Add(" en dat was in het jaar ")
			rl.Add(sYear)
			rl.Add(".  ")
			rtS = rl.Value
		End if
	rl = nothing
	return rtS
End Function

Function reSpeak(devCode)
	Dim rs as Object
	rs = hs.CreateStringClass
		rs.Add(hs.GetINISetting("speak","speakFirst","",sINI))
		rs.Add("  ")
		rs.Add(hs.DeviceString(devCode))
		hs.Speak (rs.Value,false,hs.GetINISetting("Speak","Hosts","",sINI))
		rs.Reset
	rs = Nothing
End Function

Function tempAveString(ByVal intTemperature As string) As String
	Dim fs as Object
   	Dim intRight, intLeft, aveString, iBelow as String
	Dim sBelow As String = ""
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	Try
		if NOT isNumeric(intTemperature) Then
			Return ""
			Exit Function
		End if 
		if debugMode = True Then
			hs.WriteLog(IName,"checking " & intTemperature)
		End if
		iBelow = Left(intTemperature,1)
		if iBelow = "-" Then 
			sBelow = "beneden het vriespunt. "
			intTemperature = Replace(intTemperature,"-","")
		End if
		fs = hs.CreateStringClass
			if len(trim(intTemperature)) > 1 Then
				intRight = Right(intTemperature,1)
				intLeft = Mid(intTemperature,1,(Len(intTemperature)-1) )
				Select Case intRight
					Case 0,1,2,3
						fs.Add("laagste temperatuur ")
					Case 4,5,6
						fs.Add("gemiddelde temperatuur ")
					Case 7,8,9
						fs.Add("hoogste temperatuur ")
				End Select
				if intLeft = 1 Then
					fs.Add("tientallen ")
					fs.Add(sBelow)
				Else
					fs.Add(intLeft)
					fs.Add("0's ")
					fs.Add(sBelow)
				End if
			Else
				Select Case intTemperature
					Case 0,1,2,3
						fs.Add("nabij 0 ")
					Case 4,5,6
						fs.Add("rond 5 ")
						fs.Add(sBelow)
					Case 7,8,9
						fs.Add("nabij 10 ")
						fs.Add(sBelow)
				End Select
			End If    
			aveString = fs.Value
			fs.Reset
		fs = Nothing
	Catch e as Exception
		hs.WriteLog(IName,"tempAveString: " & e.Message)
	End Try
    Return aveString
End Function

Function timeString(ByVal sDate as String) as String
	Dim aDate, aTime
	Dim ds as Object
	Dim rtS, sHour, sMins, sAPm as String
	rtS = ""
	Try
		if debugMode = True Then
			hs.WriteLog(IName,"timeString: " & sDate)
		End if
		if inStr(sDate,",") > 0 Then
			sDate = replace(sDate,":"," ")
			aDate = split(trim(sDate),",")
			sDate = aDate(1)
			aTime = split(trim(sDate)," ")
			sHour = aTime(0)
			sMins = aTime(1)
			sAPm = aTime(2)
		Else
			sHour = hour(sDate)
			sMins = minute(sDate)
			if cInt(sHour) < 12 Then
				sAPm = "in de ochtend"
			Else
				sAPm = "in de middag"
			End if
		End if
		ds = hs.CreateStringClass
			Select case sHour
				Case "1","13"
					ds.Add("een uur ")
				Case "2","14"
					ds.Add("twee uur ")
				Case "3","15"
					ds.Add("drie uur ")
				Case "4","16"
					ds.Add("vier uur ")
				Case "5","17"
					ds.Add("vijf uur ")
				Case "6","18"
					ds.Add("zes uur ")
				Case "7","19"
					ds.Add("zeven uur ")
				Case "8","20"
					ds.Add("acht uur ")
				Case "9","21"
					ds.Add("negen uur ")
				Case "10","22"
					ds.Add("tien uur ")
				Case "11","23"
					ds.Add("elf uur ")
				Case "12","0"
					ds.Add("twaalf uur ")
			End Select
			Select case sMins
				Case "1"
					ds.Add("een ")
				Case "2"
					ds.Add("twee ")
				Case "3"
					ds.Add("drie ")
				Case "4"
					ds.Add("vier ")
				Case "5"
					ds.Add("vijf ")
				Case "6"
					ds.Add("zes ")
				Case "7"
					ds.Add("zeven ")
				Case "8"
					ds.Add("acht ")
				Case "9"
					ds.Add("negen ")
				Case Else
					ds.Add(sMins)
			End Select
			ds.Add(" ")
			if lCase(sAPm) = "pm" Then
				ds.Add("smiddags")
			Else
				ds.Add("sochtends")
			End if
			rtS = ds.Value
		ds = Nothing
	Catch e as Exception
		hs.WriteLog(IName,"timeString: " & e.message)
	End Try
	Return rtS
End Function

Function weatherBarometer(Optional whichOne as String = "both") as String
	Dim wb as Object
	Dim rtS, sBar, sBarDir, unitPress as String
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	sBar = hs.GetINISetting ("WeatherInfo","Barometer","",sINI)
	sBarDir = hs.GetINISetting ("WeatherInfo","BarometerDir","",sINI)
        unitPress = hs.GetINISetting("InfoUnit","Pressure","in",sINI)
	wb = hs.CreateStringClass
		if whichOne = "barometer" OR whichOne = "both" Then
			if len(trim(sBar)) > 0 Then
				wb.Add("De barometerstand is ")
				wb.Add(sBar)
				wb.Add(" ")
				wb.Add(unitPress)
			End if
			if whichOne = "barometer" Then
				wb.Add(".  ")
			End if
		End if
		if whichOne = "both" Then
			if len(trim(sBar)) > 0 AND len(trim(sBarDir)) > 0 Then
				wb.Add(" en ")
			End if
		End if
		if whichOne = "direction" OR whichOne = "both" Then
			if len(trim(sBarDir)) > 0 Then
				if whichOne = "direction" OR len(trim(sBar)) = 0 Then
					wb.Add("De barometer is ")
				End if
				wb.Add(sBarDir)
				wb.Add(".  ")
			End if
		End if
		rtS = wb.Value
	wb = Nothing
	Return rtS
End Function

Function weatherCondition(Optional ByVal whichCond As String = "both") as String
	Dim wc as Object
	Dim rtS, dayCond, dayPrecip, nightPrecip, nightCond, unitRain as String
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	dayCond = hs.GetINISetting("WeatherInfo","Condition","",sINI)
	dayPrecip = hs.GetINISetting("Forecast","DayPrecipitation1","",sINI)
	nightCond = hs.GetINISetting("Forecast","NightCondition1","",sINI)
	nightPrecip = hs.GetINISetting("Forecast","NightPrecipitation1","",sINI)
	Try
		wc = hs.CreateStringClass
			if debugMode = true Then
				hs.WriteLog(IName,"weatherCondition: " & whichCond)
			End if
			if whichCond = "day" OR whichCond = "both" Then
				if len(trim(dayCond)) > 0 Then
					wc.Add("Gedurende de dag, ")
					'wc.Add(lCase(dayCond))
wc.Add(lcase(hs.GetINISetting("Language Conditions",dayCond,dayCond,sINI)))
					if dayPrecip > "0" Then
						wc.Add(", met een ")
						wc.Add(dayPrecip)
						wc.Add(" procent kans op neerslag")
					End If
					wc.Add(".  ")
				End if
			End if
			if whichCond = "night" OR whichCond = "both" Then
				if len(trim(nightCond)) > 0 Then
					wc.Add ("Nacht conditie wordt ")
					wc.Add(lCase(nightCond))        
					if nightPrecip > "0" Then
						wc.Add(", met een ")
						wc.Add(NightPrecip)
						wc.Add(" procent kans op neerslag")
					End if
					wc.Add(". ")
				End if
			End if
			rtS = wc.Value
		wc = Nothing
	Catch e as Exception
		hs.WriteLog(IName,"weatherCondition: " & e.Message)
		rtS= ""
	End Try
	Return rtS
End Function

Function weatherDewpoint(Optional ByVal pParms as String = "") as String
	Dim dew as Object
	Dim rtS, sDoTheDew, unitTemp as String	
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	sDoTheDew = hs.GetINISetting ("WeatherInfo","Dewpoint","",sINI)
	unitTemp = hs.GetINISetting ("InfoUnit","TempSpeak","",sINI)
	dew = hs.CreateStringClass
		if len(trim(sDoTheDew)) > 0 Then
			dew.Add("Het dauwpunt is ")
			dew.Add(sDoTheDew)
			dew.Add(" graden ")
			if len(trim(unitTemp)) > 0 Then
				dew.Add(unitTemp)
			End if
			dew.Add(".")
		End If
	rtS = dew.Value
	dew = Nothing
	Return rtS
End Function

Function weatherForecast(ByVal whichDay as String) as String
	Dim intPrecip, x, lStart, lEnd, nHigh as Integer
	Dim wf as Object
	Dim rtS, dayDate, dayName, dayHi, dayLow, dayCondition, dayPrecipitation, dayHumidity as String
	Dim thisDay, nightCondition, nightPrecipitation as String
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	wf = hs.CreateStringClass
		whichDay = lCase(whichDay)
		if Hour(Now()) > 17 Then
			thisDay = "over"
		End if
		if whichDay = "today" OR whichDay = "tonight" Then
			lStart = 1
			lEnd = 1
		Elseif whichDay = "tomorrow" Then
			lStart = 2
			lEnd = 2
		Else
			lStart = 1
			lEnd = 8
		End if
		for x = lStart to lEnd
			dayName = hs.GetINISetting ("Forecast","DayName" & x,"",sINI)
			if whichDay = "all" OR whichDay = "today" OR whichDay = "tonight" OR whichDay = "tomorrow" OR whichDay = lCase(dayName) Then
				if len(trim(dayName)) > 0 Then
					dayDate = hs.GetINISetting ("Forecast","DayDate" & x,"",sINI)
					dayLow = hs.GetINISetting ("Forecast","DayLow" & x,"",sINI)
					dayHi = hs.GetINISetting ("Forecast","DayHi" & x,"",sINI)
					dayCondition = hs.GetINISetting ("Forecast","DayCondition" & x,"",sINI)
					dayPrecipitation = hs.GetINISetting ("Forecast","DayPrecipitation" & x,"",sINI)
					nightCondition = hs.GetINISetting ("Forecast","NightCondition" & x,"",sINI)
					nightPrecipitation = hs.GetINISetting ("Forecast","NightPrecipitation" & x,"",sINI)
					wf.Add("Vooruitzicht voor ")
					wf.Add(dayName)
					if whichDay = "tonight" OR (thisDay="over" AND x=1) Then
						wf.Add(" nacht")
					End if
					wf.Add(" ")
					wf.Add(dayString(dayDate))
					wf.Add(".  ")
					if whichDay = "tonight" OR (thisDay="over" AND x=1) Then
						wf.Add(nightCondition)
						wf.Add(".  Laagste temperatuur wordt ")
						wf.Add(tempAveString(dayLow))
						wf.Add(".  ")
						if IsNumeric(nightPrecipitation) Then
							if CInt(nightPrecipitation) > 0 Then
								wf.Add("Er is ")
								wf.Add(nightPrecipitation)
								wf.Add(" procent kans op neerslag.  ")
							End if
						End if
					Else
						if len(trim(dayCondition)) > 0 Then
							wf.Add(dayCondition)
							wf.Add(".  ")
						End if
						nHigh = 0
						if len(trim(dayHi)) > 0 Then
							wf.Add("Hoogste temperatuur rond ")
							wf.Add(tempAveString(dayHi))
							nHigh = 1
						End if
						if len(trim(dayHi)) > 0 AND len(trim(dayLow)) > 0 Then
							wf.Add(" en ")
						End if
						if len(trim(dayLow)) > 0 Then
							if nHigh = 1 Then
								wf.Add("laagste ")
							Else
								wf.Add("Laagste temperatuur ")
							End if
							wf.Add("rond de ")
							wf.Add(tempAveString(dayLow))
						End if
						wf.Add(".  ")
						intPrecip=0
						if IsNumeric(dayPrecipitation) Then
							if CInt(dayPrecipitation) > 0 Then
								wf.Add("Er is een ")
								wf.Add(dayPrecipitation)
								wf.Add(" procent kans op neerslag gedurende de dag.  ")
								intPrecip=1
							End if
						End If
						if IsNumeric(nightPrecipitation) AND intPrecip = 0 Then
							if CInt(nightPrecipitation) > 0 Then
								wf.Add("Er is een ")
								wf.Add(nightPrecipitation)
								wf.Add(" procent kans op neerslag gedurende de nacht.  ")
							End if
						End if
					End if
				End if
			End if
		Next
		rtS = wf.Value
	wf = Nothing
	Return rtS
End Function

Function weatherHiLow(Optional ByVal whichTemp as String = "both") as String
	Dim wt as Object
	Dim rtS, dayHi, dayLow, unitTemp as String
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	dayHi = hs.GetINISetting("Forecast","DayHi1","",sINI)
	dayLow = hs.GetINISetting("Forecast","DayLow1","",sINI)
	unitTemp = hs.GetINISetting("InfoUnit","tempSpeak","",sINI)
	wt = hs.CreateStringClass
		whichTemp = lCase(whichTemp)
		if whichTemp = "high" OR whichTemp = "both" Then
			if len(trim(dayHi)) > 0 Then
				if IsNumeric(dayHi) Then
					wt.Add("De hoogste temperatuur voor vandaag wordt ongeveer ")
					wt.Add(DayHi)
					wt.Add(" graden ")
					if len(trim(unitTemp)) > 0 Then
						wt.Add(unitTemp)
					End if
					wt.Add(".  ")
				End If
			End if
		End if
		if whichTemp = "low" OR whichTemp = "both" Then
			if len(trim(dayLow)) > 0 Then
				if IsNumeric(dayLow) Then
					wt.Add("De laagste temperatuur voor vandaag wordt ongeveer ")
					wt.Add(DayLow)
					wt.Add(" graden ")
					if len(trim(unitTemp)) > 0 Then
						wt.Add(unitTemp)
					End if
					wt.Add(".  ")
				End If        
			End if
		End if
		rtS = wt.Value
	wt = nothing
	Return rtS
End Function

Function weatherHumidity(Optional ByVal sParms as String ="") as String
	Dim wh as Object
	Dim rtS, sHumid as String
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	sHumid = hs.GetINISetting ("WeatherInfo","Humidity","not available",sINI)
	wh = hs.CreateStringClass
		if len(trim(sHumid)) > 0 Then
			wh.Add("De luchtvochtigheid is ")
			wh.Add(sHumid)
			wh.Add(" procent.  ")
		End If
		rtS = wh.Value
	wh = Nothing
	Return rtS
End Function

Function weatherTemp(Optional ByVal whichTemp as String = "both") as String
	Dim wt as Object
	Dim rtS, curTemp, feelsLike, unitTemp as String
    unitTemp = hs.GetINISetting("InfoUnit","tempSpeak","",sINI)
	curTemp = hs.GetINISetting ("WeatherInfo","CurrentTemp","0",sINI)
	feelsLike = hs.GetINISetting ("WeatherInfo","FeelsLike","0",sINI)
	Try
		if debugMode = true Then
			hs.WriteLog(IName,"weatherTemp: " & whichTemp)
		End if
		wt = hs.CreateStringClass
			if whichTemp = "current" OR whichTemp = "both" Then
				if len(trim(curTemp)) > 0 Then
					wt.Add("De temperatuur is ")
					wt.Add(curTemp)
					wt.Add(" graden ")
					if len(trim(unitTemp)) > 0 Then
						wt.Add(unitTemp)
					End if
					if whichTemp = "current" OR len(trim(feelsLike)) = 0 OR feelsLike = "N/A" Then
						wt.Add(".  ")
					End if
				End if
			End if
			if whichTemp = "feels" OR whichTemp = "both" Then
				if len(trim(feelsLike)) > 0 AND feelsLike <> "N/A" Then
					if whichTemp = "both" AND len(trim(curTemp)) > 0 Then
						if curTemp <> feelsLike Then
							wt.Add(",  de gevoelstemperatuur is ")
							wt.Add(feelsLike)
							wt.Add(" graden ")
							if len(trim(unitTemp)) > 0 Then
								wt.Add(unitTemp)
							End if
							wt.Add(".  ")
						Else
							wt.Add(".  ")
						End if
					Else
						wt.Add("Op het moment is het volgens de warmte index ")
						wt.Add(feelsLike)
						wt.Add(" graden ")
						if len(trim(unitTemp)) > 0 Then
							wt.Add(unitTemp)
						End if
						wt.Add(".  ")
					End if
				End if
			End if
			rtS = wt.Value
		wt = Nothing
	Catch e as Exception
		hs.WriteLog(IName,"weatherTemp: " & e.Message)
		rtS= ""
	End Try
	Return rtS
End Function

Function weatherTempDay(Optional ByVal whichDay as String = "today") as String
	Dim x as Integer
	Dim wt as Object
	Dim rtS, sDayName as String
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	wt = hs.CreateStringClass
		if whichDay = "today" Then
			wt.Add(weatherTemp("both"))
		Else
			wt.Add("De temperatuur voor ")
			wt.Add(whichDay)
			wt.Add(" wordt ongeveer ")
			if whichDay = "tonight" Then
				wt.Add(hs.GetINISetting("Forecast","DayLow1","",sINI))
			Elseif whichDay = "tomorrow" Then
				wt.Add(hs.GetINISetting("Forecast","DayHi2","",sINI))
			Else
				for x = 1 to 8
					sDayName = hs.GetINISetting("Forecast","DayName" & x,"",sINI)
					if lCase(sDayName) = lCase(whichDay) Then
						wt.Add(hs.GetINISetting("Forecast","DayHi" & x,"",sINI))
						wt.Add(" graden en de laagste temperatuur rond de  ")
						wt.Add(hs.GetINISetting("Forecast","DayLow" & x,"",sINI))
						Exit for
					End if
				Next
			End if
			wt.Add(" graden.  ")
		End if
		rtS = wt.Value
	wt= Nothing	
	Return rtS
End function

Function weatherUpdated(Optional ByVal whichTime as String = "") as String
	Dim wu as Object
	Dim rtS, sDayName, sDayDate, sUpdate as String
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	sDayName = hs.GetINISetting("Forecast","DayName1","",sINI)
	sDayDate = hs.GetINISetting("Forecast","DayDate1","",sINI)
	sUpdate = hs.GetINISetting("Location","TimeChecked","",sINI)
	wu = hs.CreateStringClass
		wu.Add("Het weer ")
		if len(trim(sDayName)) > 0 Then
			wu.Add ("voor ")
			wu.Add (sDayName)
			if len(trim(sDayDate)) > 0 Then
				wu.Add (", ")
				wu.Add (trim(dayString(sDayDate)))
			End if
			wu.Add(".  ")
		End if
		if len(trim(sUpdate)) > 0 Then
			wu.Add ("Dit weerbericht was ververst op ")
			wu.Add (trim(dayString(sUpdate)))
			wu.Add (" om ")
			wu.Add (timeString(sUpdate))
			wu.Add (".  ")
		End If
		rtS = wu.Value
	wu = Nothing
	Return rtS
End Function

Function weatherVisibility(Optional ByVal sParms as String = "") as String
	Dim wv as Object
	Dim rtS, sVisible, unitDist as String
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	sVisible = hs.GetINISetting ("WeatherInfo","Visibility","",sINI)
    unitDist = hs.GetINISetting("InfoUnit","Distance","mi",sINI)
	wv = hs.CreateStringClass
		if len(trim(sVisible)) > 0 Then
			wv.Add("Het zicht is ")
			wv.Add(sVisible)
			if IsNumeric(sVisible) Then
				wv.Add(" ")
				wv.Add(unitDist)
			End if
			wv.Add(".  ")
		End If
		rtS = wv.Value
	wv = Nothing
	Return rtS
End Function

Function weatherWind(Optional whichInfo as String = "all") as String
	Dim ww as Object
	Dim rtS, unitSpeed, sWindDegrees, sWindgust, sWindSpeed, sWindDirection as String
	debugMode = hs.GetINISetting ("Debug","debugMode","False",sINI)
	sWindSpeed = hs.GetINISetting ("WeatherInfo","WindSpeed","",sINI)
	sWindDirection = hs.GetINISetting ("WeatherInfo","WindDirection","",sINI)
	sWindgust = hs.GetINISetting ("WeatherInfo","Windgust","",sINI)
	sWindDegrees = hs.GetINISetting ("WeatherInfo","WindDegrees","",sINI)
    unitSpeed = hs.GetINISetting("InfoUnit","Speed","mph",sINI)
	Try
		ww = hs.CreateStringClass
			if whichInfo = "wind" OR whichInfo = "all" Then
				if len(trim(sWindSpeed)) > 0 Then
					ww.Add("De windsnelheid is ")
					ww.Add(sWindSpeed)
					if isNumeric(sWindSpeed) Then
						ww.Add(" ")
						ww.Add(unitSpeed)
					End if
					if whichInfo <> "all" Then
						ww.Add(".  ")
					End if
				End if
			End if
			if whichInfo = "direction" OR whichInfo = "all" Then
				if whichInfo = "direction" Then
					ww.Add("De wind is ")
				Else
					ww.Add(", ")
				End if
				if lCase(sWindDirection) <> "calm" Then
					sWindDirection = directionText(sWindDirection)
					ww.add(" uit de richting ")
					ww.Add(sWindDirection)
				Else
					if whichInfo = "all" Then
						ww.Add(" en is ")
					End if
					ww.Add(sWindDirection)
				End if
				ww.Add(".  ")
			End if
			if whichInfo = "gust" OR whichInfo = "all" Then
				if len(trim(sWindgust)) > 0 AND sWindGust <> "N/A" Then
					if cInt(sWindgust) > 0 Then
						ww.Add("Windstoten van ")
						ww.Add(sWindgust)
						ww.Add(" ")
						ww.Add(unitSpeed)
						ww.Add(".  ")
					End if
				End if
			End if
			if whichInfo = "degrees" OR whichInfo = "all" Then
				if len(trim(sWindDegrees)) > 0 Then
					ww.Add("De windrichting is ")
					ww.Add(hs.GetINISetting ("WeatherInfo","WindDegrees","",sINI))
					ww.Add(".  ")
				End if
			End if
			rtS = ww.Value
		ww = Nothing
	Catch e as Exception
		hs.WriteLog(Iname,"weatherWind: " & e.Message)
		rtS = ""
	End Try
	Return rtS
End Function
